@@ -157,7 +157,7 @@ void createISOImage(QString &sourceDirectory)
 
 void burnISOImage(int mediaType, bool bEraseDVDRW)
 {
-    QString dvdDrive = gContext->GetSetting(" MythArchiveDVDLocation", "/dev/dvd");
+    QString dvdDrive = gContext->GetSetting("MythArchiveDVDLocation", "/dev/dvd");
     VERBOSE(VB_JOBQUEUE, "Burning ISO image to " + dvdDrive);
 
     QString tempDirectory = gContext->GetSetting("MythArchiveTempDir", "");
@@ -297,7 +297,7 @@ int NativeArchive::doNativeArchive(const QString &jobFile)
         burnISOImage(mediaType, bEraseDVDRW);
 
     // make sure the files we created are read/writable by all 
-    system("chmod -R a+rw-x+X " + saveDirectory);
+    //system("chmod -R a+rw-x+X " + saveDirectory);
 
     VERBOSE(VB_JOBQUEUE, "Native archive job completed OK");
 
@@ -1917,8 +1917,10 @@ int getFileInfo(QString inFile, QString outFile, int lenMethod)
 
                 if (st->codec->sample_aspect_ratio.den && st->codec->sample_aspect_ratio.num)
                 {
-                    float sample_aspect_ratio = av_q2d(st->codec->sample_aspect_ratio);
-                    float aspect_ratio = ((float)st->codec->width / st->codec->height) * sample_aspect_ratio;
+                    float aspect_ratio = av_q2d(st->codec->sample_aspect_ratio);
+                    if (QString(inputFC->iformat->name) != "nuv")
+                        aspect_ratio = ((float)st->codec->width / st->codec->height) * aspect_ratio;
+
                     stream.setAttribute("aspectratio", aspect_ratio);
                 }
                 else
@@ -1926,6 +1928,17 @@ int getFileInfo(QString inFile, QString outFile, int lenMethod)
 
                 stream.setAttribute("id", st->id);
 
+                if (st->start_time != AV_NOPTS_VALUE)
+                {
+                    int secs, us;
+                    secs = st->start_time / AV_TIME_BASE;
+                    us = st->start_time % AV_TIME_BASE;
+                    stream.setAttribute("start_time", QString("%1.%2")
+                            .arg(secs).arg(av_rescale(us, 1000000, AV_TIME_BASE)));
+                }
+                else
+                    stream.setAttribute("start_time", 0);
+
                 streams.appendChild(stream);
 
                 switch (lenMethod)
@@ -1991,6 +2004,17 @@ int getFileInfo(QString inFile, QString outFile, int lenMethod)
                 stream.setAttribute("samplerate", st->codec->sample_rate);
                 stream.setAttribute("bitrate", st->codec->bit_rate);
 
+                if (st->start_time != AV_NOPTS_VALUE)
+                {
+                    int secs, us;
+                    secs = st->start_time / AV_TIME_BASE;
+                    us = st->start_time % AV_TIME_BASE;
+                    stream.setAttribute("start_time", QString("%1.%2")
+                            .arg(secs).arg(av_rescale(us, 1000000, AV_TIME_BASE)));
+                }
+                else
+                    stream.setAttribute("start_time", 0);
+
                 streams.appendChild(stream);
 
                 break;
