@@ -8,17 +8,18 @@
 
 */
 
-#include <iostream>
-using namespace std;
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
+#include <unistd.h>
 
-#include <dvdread/dvd_reader.h>
-#include <dvdread/ifo_types.h>
-#include <dvdread/ifo_read.h>
-#include <dvdread/nav_read.h>
+#include <algorithm>
 
 #include <qdatetime.h>
 #include <qdir.h>
 #include <qapplication.h>
+#include <qdeepcopy.h>
+#include <qprocess.h>
 
 #include <mythtv/mythcontext.h>
 #include <mythtv/mythdbcon.h>
@@ -26,6 +27,16 @@ using namespace std;
 #include "jobthread.h"
 #include "mtd.h"
 #include "threadevents.h"
+#include "dvdprobe.h"
+
+namespace {
+    struct delete_file {
+        bool operator()(const QString &filename) {
+            VERBOSE(VB_GENERAL, QString("Deleting file: %1").arg(filename));
+            return QDir::current().remove(filename);
+        }
+    };
+}
 
 JobThread::JobThread(MTD *owner, const QString &start_string, int nice_priority)
           :QThread()
@@ -44,7 +55,8 @@ JobThread::JobThread(MTD *owner, const QString &start_string, int nice_priority)
 
 void JobThread::run()
 {
-    cerr << "jobthread.o: Somebody ran an actual (base class) JobThread. I don't think that's supposed to happen." << endl;
+    VERBOSE(VB_IMPORTANT, "Somebody ran an actual (base class) JobThread. I"
+            " don't think that's supposed to happen.");
 }
 
 bool JobThread::keepGoing()
@@ -56,6 +68,18 @@ bool JobThread::keepGoing()
     return false;
 }
 
+QString JobThread::getProblem()
+{
+    QMutexLocker qml(&problem_string_mutex);
+    return QDeepCopy<QString>(problem_string);
+}
+
+QString JobThread::getJobString()
+{
+    QMutexLocker qml(&job_string_mutex);
+    return QDeepCopy<QString>(job_string);
+}
+
 void JobThread::updateSubjobString( int seconds_elapsed, 
                                     const QString & pre_string)
 {
@@ -96,7 +120,7 @@ void JobThread::setSubProgress(double some_value, uint priority)
 {
     if(priority > 0)
     {
-        while(!sub_progress_mutex.tryLock())
+        while(!subjob_progress_mutex.tryLock())
         {
             sleep(priority);
         }
@@ -107,20 +131,20 @@ void JobThread::setSubProgress(double some_value, uint priority)
     }
     else
     {
-        sub_progress_mutex.lock();
+        subjob_progress_mutex.lock();
         if(!cancel_me)
         {
             subjob_progress = some_value;
         }
     }
-    sub_progress_mutex.unlock();
+    subjob_progress_mutex.unlock();
 }
 
 void JobThread::setSubName(const QString &new_name, uint priority)
 {
     if(priority > 0)
     {
-        while(!sub_name_mutex.tryLock())
+        while(!subjob_name_mutex.tryLock())
         {
             sleep(1);
         }
@@ -131,16 +155,28 @@ void JobThread::setSubName(const QString &new_name, uint priority)
     }
     else
     {
-        sub_name_mutex.lock();
+        subjob_name_mutex.lock();
         if(!cancel_me)
         {
             subjob_name = new_name;
         }
     }
-    sub_name_mutex.unlock();
+    subjob_name_mutex.unlock();
     
 }
 
+QString JobThread::getJobName()
+{
+    QMutexLocker qml(&job_name_mutex);
+    return QDeepCopy<QString>(job_name);
+}
+
+QString JobThread::getSubName()
+{
+    QMutexLocker qml(&subjob_name_mutex);
+    return QDeepCopy<QString>(subjob_name);
+}
+
 void JobThread::problem(const QString &a_problem)
 {
     //
@@ -150,7 +186,7 @@ void JobThread::problem(const QString &a_problem)
     ErrorEvent *ee = new ErrorEvent(a_problem);
     QApplication::postEvent(parent, ee);
     
-    problem_string = a_problem;
+    setProblem(a_problem);
     
 }
 
@@ -166,11 +202,101 @@ void JobThread::sendLoggingEvent(const QString &event_string)
     QApplication::postEvent(parent, le);
 }
 
+void JobThread::setJobName(const QString &jname)
+{
+    QMutexLocker qml(&job_name_mutex);
+    job_name = jname;
+}
+
+void JobThread::setProblem(const QString &prob)
+{
+    QMutexLocker qml(&problem_string_mutex);
+    problem_string = prob;
+}
 
 /*
 ---------------------------------------------------------------------
 */
 
+namespace
+{
+    class MutexUnlocker
+    {
+      public:
+        MutexUnlocker(QMutex *mutex) : m_mutex(mutex)
+        {
+            if (!(m_mutex && m_mutex->locked()))
+            {
+                VERBOSE(VB_IMPORTANT,
+                        QString("%1: Invalid mutex passed to MutexUnlocker")
+                        .arg(__FILE__));
+            }
+        }
+
+        ~MutexUnlocker()
+        {
+            m_mutex->unlock();
+        }
+
+      private:
+        QMutex *m_mutex;
+    };
+
+    template <typename HTYPE>
+    struct is_handle_null
+    {
+        bool operator()(HTYPE handle)
+        {
+            return handle == NULL;
+        }
+    };
+
+    template <typename HTYPE>
+    struct is_bad_stdio_handle
+    {
+        bool operator()(HTYPE handle)
+        {
+            return handle == -1;
+        }
+    };
+
+
+    template <typename HTYPE, typename CLEANF_RET = void,
+             typename handle_checker = is_handle_null<HTYPE> >
+    class SmartHandle
+    {
+      private:
+        typedef CLEANF_RET (*clean_fun_t)(HTYPE);
+
+      public:
+        SmartHandle(HTYPE handle, clean_fun_t cleaner) : m_handle(handle),
+                                                         m_cleaner(cleaner)
+        {
+        }
+
+        ~SmartHandle() {
+            handle_checker hc;
+            if (!hc(m_handle))
+            {
+                m_cleaner(m_handle);
+            }
+        }
+
+        HTYPE get()
+        {
+            return m_handle;
+        }
+
+        HTYPE operator->() {
+            return m_handle;
+        }
+
+      private:
+        HTYPE m_handle;
+        clean_fun_t m_cleaner;
+    };
+}
+
 DVDThread::DVDThread(MTD *owner, 
                      QMutex *drive_mutex, 
                      const QString &dvd_device, 
@@ -185,20 +311,21 @@ DVDThread::DVDThread(MTD *owner,
     dvd_device_location = dvd_device;
     dvd_title = track - 1;
     destination_file_string = dest_file;
-    ripfile = NULL;
     rip_name = name;
 }
 
 void DVDThread::run()
 {
-    cerr << "jobthread.o: Somebody ran an actual (base class) DVDThread. I don't think that's supposed to happen." << endl;
+    VERBOSE(VB_IMPORTANT, "Somebody ran an actual (base class) DVDThread. I"
+            " don't think that's supposed to happen.");
 }
 
 
 bool DVDThread::ripTitle(int title_number,
                          const QString &to_location,
                          const QString &extension,
-                         bool multiple_files)
+                         bool multiple_files,
+                         QStringList *output_files)
 {
     //
     //  Can't do much until I have a
@@ -229,10 +356,11 @@ bool DVDThread::ripTitle(int title_number,
         }
     }    
 
+    MutexUnlocker qmul(dvd_device_access);
+
     if(!keepGoing())
     {
         problem("abandoned job because master control said we need to shut down");
-        dvd_device_access->unlock();
         return false;
     }
 
@@ -244,17 +372,11 @@ bool DVDThread::ripTitle(int title_number,
     //  Lets open our destination file
     //
     
-    if(ripfile)
+    RipFile ripfile(to_location, extension, true);
+    if(!ripfile.open(IO_WriteOnly | IO_Raw | IO_Truncate, multiple_files))
     {
-        cerr << "jobthread.o: How is it that you already have a ripfile set?" << endl;
-        delete ripfile;
-        ripfile = NULL;
-    }
-    ripfile = new RipFile(to_location, extension);
-    if(!ripfile->open(IO_WriteOnly | IO_Raw | IO_Truncate, multiple_files))
-    {
-        problem(QString("DVDPerfectThread could not open output file: %1").arg(ripfile->name()));
-        dvd_device_access->unlock();
+        problem(QString("DVDPerfectThread could not open output file: %1")
+                .arg(ripfile.name()));
         return false;
     }
 
@@ -265,27 +387,19 @@ bool DVDThread::ripTitle(int title_number,
     
     int angle = 0;  // Change that at some point
 
-    the_dvd = DVDOpen(dvd_device_location);
-    if(!the_dvd)
+    SmartHandle<dvd_reader_t *> the_dvd(DVDOpen(dvd_device_location),
+            DVDClose);
+    if(!the_dvd.get())
     {
         problem(QString("DVDPerfectThread could not access this dvd device: %1").arg(dvd_device_location));
-        ripfile->remove();
-        delete ripfile;
-        ripfile = NULL;
-        dvd_device_access->unlock();
         return false;
     }
 
 
-    ifo_handle_t *vmg_file = ifoOpen( the_dvd, 0);
-    if(!vmg_file)
+    SmartHandle<ifo_handle_t *> vmg_file(ifoOpen(the_dvd.get(), 0), ifoClose);
+    if(!vmg_file.get())
     {
         problem("DVDPerfectThread could not open VMG info.");
-        ripfile->remove();
-        delete ripfile;
-        ripfile = NULL;
-        DVDClose(the_dvd);
-        dvd_device_access->unlock();
         return false;
     }
     tt_srpt_t *tt_srpt = vmg_file->tt_srpt;
@@ -297,25 +411,15 @@ bool DVDThread::ripTitle(int title_number,
     if(title_number < 0 || title_number > tt_srpt->nr_of_srpts )
     {
         problem(QString("DVDPerfectThread could not open title number %1").arg(title_number + 1));
-        ripfile->remove();
-        delete ripfile;
-        ripfile = NULL;
-        ifoClose(vmg_file);
-        DVDClose(the_dvd);
-        dvd_device_access->unlock();
         return false;
     }
 
-    ifo_handle_t *vts_file = ifoOpen(the_dvd, tt_srpt->title[title_number].title_set_nr);
-    if(!vts_file)
+    SmartHandle<ifo_handle_t *> vts_file(
+            ifoOpen(the_dvd.get(), tt_srpt->title[title_number].title_set_nr),
+            ifoClose);
+    if(!vts_file.get())
     {
         problem("DVDPerfectThread could not open the title's info file");
-        ripfile->remove();
-        delete ripfile;
-        ripfile = NULL;
-        ifoClose(vmg_file);
-        DVDClose(the_dvd);
-        dvd_device_access->unlock();
         return false;
     }
 
@@ -348,19 +452,14 @@ bool DVDThread::ripTitle(int title_number,
     //  OK ... now actually open
     //    
     
-    title = DVDOpenFile(the_dvd, 
-                        tt_srpt->title[ title_number ].title_set_nr, 
-                        DVD_READ_TITLE_VOBS );
-    if(!title)
+    SmartHandle<dvd_file_t *> title(
+            DVDOpenFile(the_dvd.get(),
+                    tt_srpt->title[title_number].title_set_nr,
+                    DVD_READ_TITLE_VOBS),
+            DVDCloseFile);
+    if(!title.get())
     {
         problem("DVDPerfectThread could not open the title's actual VOB(s)");
-        ripfile->remove();
-        delete ripfile;
-        ripfile = NULL;
-        ifoClose(vts_file);
-        ifoClose(vmg_file);
-        DVDClose(the_dvd);
-        dvd_device_access->unlock();
         return false;
     }
     
@@ -368,6 +467,8 @@ bool DVDThread::ripTitle(int title_number,
 
     QTime job_time;
     job_time.start();
+
+    std::vector<unsigned char> video_data(1024 * DVD_VIDEO_LB_LEN);
     
     int next_cell = start_cell;    
     for(int cur_cell = start_cell; next_cell < cur_pgc->nr_of_cells; )
@@ -405,18 +506,12 @@ bool DVDThread::ripTitle(int title_number,
             //  Read the NAV packet.
             //            
             
-            int len = DVDReadBlocks( title, (int) cur_pack, 1, video_data );
+            int len = DVDReadBlocks(title.get(), (int) cur_pack, 1, 
+                                    &video_data[0]);
             if( len != 1)
             {
-                problem(QString("DVDPerfectThread read failed for block %1").arg(cur_pack));
-                ifoClose(vts_file);
-                ifoClose(vmg_file);
-                DVDCloseFile( title );
-                DVDClose(the_dvd);
-                dvd_device_access->unlock();
-                ripfile->remove();
-                delete ripfile;
-                ripfile = NULL;
+                problem(QString("DVDPerfectThread read failed for block %1")
+                        .arg(cur_pack));
                 return false;
             }
             
@@ -429,7 +524,7 @@ bool DVDThread::ripTitle(int title_number,
             //  Parse the contained dsi packet
             //
             
-            navRead_DSI(&dsi_pack, &(video_data[ DSI_START_BYTE ]) );
+            navRead_DSI(&dsi_pack, &video_data[DSI_START_BYTE]);
             //  and another assertion here: assert( cur_pack == dsi_pack.dsi_gi.nv_pck_lbn );
             
             //
@@ -456,21 +551,14 @@ bool DVDThread::ripTitle(int title_number,
             //  Read in and output cursize packs
             //
             
-            len = DVDReadBlocks( title, (int)cur_pack, cur_output_size, video_data );
+            len = DVDReadBlocks(title.get(), (int)cur_pack, cur_output_size,
+                                &video_data[0]);
             if( len != (int) cur_output_size )
             {
                 problem(QString("DVDPerfectThread read failed for %1 blocks at %2") 
                         .arg(cur_output_size)
                         .arg(cur_pack)
                        );
-                ripfile->remove();
-                delete ripfile;
-                ripfile = NULL;
-                ifoClose(vts_file);
-                ifoClose(vmg_file);
-                DVDCloseFile( title );
-                DVDClose(the_dvd);
-                dvd_device_access->unlock();
                 return false;
             }
             
@@ -478,17 +566,10 @@ bool DVDThread::ripTitle(int title_number,
             overall_progress = subjob_progress * sub_to_overall_multiple;
             updateSubjobString(job_time.elapsed() / 1000, 
                                QObject::tr("Ripping to file ~"));
-            if(!ripfile->writeBlocks(video_data, cur_output_size * DVD_VIDEO_LB_LEN))
+            if(!ripfile.writeBlocks(&video_data[0],
+                            cur_output_size * DVD_VIDEO_LB_LEN))
             {
                 problem("Couldn't write blocks during a rip. Filesystem size exceeded? Disc full?");
-                ripfile->remove();
-                delete ripfile;
-                ripfile = NULL;
-                DVDCloseFile( title );
-                ifoClose(vts_file);
-                ifoClose(vmg_file);
-                DVDClose(the_dvd);
-                dvd_device_access->unlock();
                 return false;
             }
 
@@ -504,14 +585,6 @@ bool DVDThread::ripTitle(int title_number,
             if(!keepGoing())
             {
                 problem("abandoned job because master control said we need to shut down");
-                ripfile->remove();
-                delete ripfile;
-                ripfile = NULL;
-                DVDCloseFile( title );
-                ifoClose(vts_file);
-                ifoClose(vmg_file);
-                DVDClose(the_dvd);
-                dvd_device_access->unlock();
                 return false;
             }
         }
@@ -521,24 +594,167 @@ bool DVDThread::ripTitle(int title_number,
     //  Wow, we're done.
     //
 
-    ifoClose(vts_file);
-    ifoClose(vmg_file);
-    DVDCloseFile( title );
-    DVDClose(the_dvd);
-    ripfile->close();
-    dvd_device_access->unlock();
+    QStringList sl = ripfile.close();
+    if (output_files) *output_files = sl;
+
     sendLoggingEvent("job thread finished ripping dvd title");
     return true;
 }
 
 DVDThread::~DVDThread()
 {
-    if(ripfile);
+}
+
+/*
+---------------------------------------------------------------------
+*/
+
+DVDISOCopyThread::DVDISOCopyThread(MTD *owner, 
+                                   QMutex *drive_mutex, 
+                                   const QString &dvd_device, 
+                                   int track, 
+                                   const QString &dest_file, 
+                                   const QString &name,
+                                   const QString &start_string,
+                                   int nice_priority)
+                 :DVDThread(owner,
+                            drive_mutex, 
+                            dvd_device, 
+                            track, 
+                            dest_file, 
+                            name,
+                            start_string,
+                            nice_priority)
+
+{
+
+    sendLoggingEvent(QString("Using DVD source: %1").arg(dvd_device));
+}
+
+void DVDISOCopyThread::run()
+{
+    //
+    //  Be nice
+    //
+    
+    nice(nice_level);
+    setJobName(QString(QObject::tr("ISO copy of %1")).arg(rip_name));
+    if(keepGoing())
     {
-        delete ripfile;
+        copyFullDisc();
     }
 }
 
+bool DVDISOCopyThread::copyFullDisc(void)
+{
+    bool loop = true;
+
+    setSubName(QObject::tr("Waiting for access to DVD"), 1);
+
+    while(loop)
+    {
+        if(dvd_device_access->tryLock())
+        {
+            loop = false;
+        }
+        else
+        {
+            if(keepGoing())
+            {
+                sleep(5);
+            }
+            else
+            {
+                problem("abandoned job because master control said we need to shut down");
+                return false;
+            }
+        }
+    }
+
+    MutexUnlocker qmul(dvd_device_access);
+    if(!keepGoing())
+    {
+        problem("abandoned job because master control said we need to shut down");
+        return false;
+    }
+
+    RipFile ripfile(destination_file_string, ".iso", true);
+    if(!ripfile.open(IO_WriteOnly | IO_Raw | IO_Truncate, false))
+    {
+        problem(QString("DVDISOCopyThread could not open output file: %1")
+                .arg(ripfile.name()));
+        return false;
+    }
+
+    sendLoggingEvent(QString("ISO DVD image copy to: %1").arg(ripfile.name()));
+
+    SmartHandle<int, int, is_bad_stdio_handle<int> > file(
+            open(dvd_device_location, O_RDONLY), close);
+    if(file.get() == -1)
+    {
+        problem(QString("DVDISOCopyThread could not open dvd device: %1")
+                .arg(dvd_device_location));
+        return false;
+    }
+
+    off_t dvd_size = lseek(file.get(), 0, SEEK_END);
+    lseek(file.get(), 0, SEEK_SET);
+
+    const int buf_size = 1024 * 1024;
+    unsigned char buffer[buf_size];
+    long long total_bytes(0);
+
+    QTime job_time;
+    job_time.start();
+
+    while( 1 )
+    {
+        int bytes_read = read(file.get(), buffer, buf_size);
+        if(bytes_read == -1)
+        {
+            perror("read");
+            problem(QString("DVDISOCopyThread dvd device read error"));
+            return false;
+        }
+        if(bytes_read == 0)
+        {
+            break;
+        }
+
+        if(!ripfile.writeBlocks(buffer, bytes_read))
+        {
+            problem(QString("DVDISOCopyThread rip file write error"));
+            return false;
+        }
+
+        total_bytes += bytes_read;
+
+        setSubProgress((double) (total_bytes) / (double) (dvd_size), 1);
+        overall_progress = subjob_progress * sub_to_overall_multiple;
+        updateSubjobString(job_time.elapsed() / 1000,
+                           QObject::tr("Ripping to file ~"));
+
+        //
+        //  Escape out and clean up if mtd main thread
+        //  tells us to
+        //
+            
+        if(!keepGoing())
+        {
+            problem("abandoned job because master control said we need to shut down");
+            return false;
+        }
+    }
+
+    ripfile.close();
+    sendLoggingEvent("job thread finished copying ISO image");
+    return true;
+}
+
+DVDISOCopyThread::~DVDISOCopyThread()
+{
+}
+
 /*
 ---------------------------------------------------------------------
 */
@@ -570,7 +786,7 @@ void DVDPerfectThread::run()
     //
     
     nice(nice_level);
-    job_name = QString(QObject::tr("Perfect DVD Rip of %1")).arg(rip_name);
+    setJobName(QString(QObject::tr("Perfect DVD Rip of %1")).arg(rip_name));
     if(keepGoing())
     {
         ripTitle(dvd_title, destination_file_string, ".vob", true);
@@ -659,12 +875,12 @@ void DVDTranscodeThread::run()
         }
         if(two_pass)
         {
-            job_name = QString(QObject::tr("Transcode of %1")).arg(rip_name);
+            setJobName(QString(QObject::tr("Transcode of %1")).arg(rip_name));
             sub_to_overall_multiple = 0.333333333;
         }
         else
         {
-            job_name = QString(QObject::tr("Transcode of %1")).arg(rip_name);
+            setJobName(QString(QObject::tr("Transcode of %1")).arg(rip_name));
             sub_to_overall_multiple = 0.50;
         }
     }
@@ -673,10 +889,11 @@ void DVDTranscodeThread::run()
     //  Rip VOB to working directory
     //
 
+    QStringList output_files;
     if(keepGoing())
     {
         QString rip_file_string = QString("%1/vob/%2").arg(working_directory->path()).arg(rip_name);
-        if(!ripTitle(dvd_title, rip_file_string, ".vob", true))
+        if(!ripTitle(dvd_title, rip_file_string, ".vob", true, &output_files))
         {
             cleanUp(); 
             return;
@@ -708,7 +925,7 @@ void DVDTranscodeThread::run()
             }
             else
             {
-                problem("abandonded job because master control said we need to shut down");
+                problem("abandoned job because master control said we need to shut down");
                 return;
             }
         }
@@ -738,7 +955,13 @@ void DVDTranscodeThread::run()
                 wipeClean();
             }
         }
-    }    
+    }
+
+    if (!gContext->GetNumSetting("mythdvd.mtd.SaveTranscodeIntermediates", 0)) {
+        // remove any temporary titles that are now transcoded
+        std::for_each(output_files.begin(), output_files.end(), delete_file());
+    }
+
     cleanUp();
 }
 
@@ -829,7 +1052,8 @@ bool DVDTranscodeThread::buildTranscodeCommandLine(int which_run)
                                      " a_bitrate,   "
                                      " input,       "
                                      " name,        "
-                                     " two_pass     "
+                                     " two_pass,    "
+                                     " tc_param     "
                                      
                                      " FROM dvdtranscode WHERE intid = %1 ;")
                                      .arg(quality);
@@ -875,6 +1099,7 @@ bool DVDTranscodeThread::buildTranscodeCommandLine(int which_run)
     int   input_setting = a_query.value(21).toInt();
     QString        name = a_query.value(22).toString();
                two_pass = a_query.value(23).toBool();
+    QString    tc_param = a_query.value(24).toString();
     
     //
     //  And now, another query to get frame rate code and
@@ -924,18 +1149,20 @@ bool DVDTranscodeThread::buildTranscodeCommandLine(int which_run)
     tc_arguments.append(QString("%1/vob/").arg(working_directory->path()));
     tc_arguments.append("-g");
     tc_arguments.append(QString("%1x%2").arg(input_hsize).arg(input_vsize));
-    tc_arguments.append("-f");
-    tc_arguments.append(QString("0,%1").arg(fr_code));
-                         
-                         
-                         
+
+    if (!gContext->GetNumSetting("mythvideo.TrustTranscodeFRDetect"))
+    {
+        tc_arguments.append("-f");
+        tc_arguments.append(QString("0,%1").arg(fr_code));
+    }
+
     tc_arguments.append("-M");
     tc_arguments.append(QString("%1").arg(sync_mode));
-    
+
     if(use_yv12)
     {
         tc_arguments.append("-V");
-    }    
+    }
 
     //
     //  The order of these is defined by transcode
@@ -1003,11 +1230,16 @@ bool DVDTranscodeThread::buildTranscodeCommandLine(int which_run)
     else
         tc_arguments.append(codec);
 
-    if(codec_param.length() > 0)
+    if(codec_param.length())
     {
         tc_arguments.append("-F");
         tc_arguments.append(codec_param);
     }
+
+    if(tc_param.length())
+    {
+        tc_arguments += QStringList::split(" ", tc_param);
+    }
     
     if(bitrate > 0)
     {
@@ -1232,13 +1464,6 @@ void DVDTranscodeThread::cleanUp()
     //
     if(working_directory)
     {
-        if(ripfile)
-        {
-            ripfile->remove();
-            delete ripfile;
-            ripfile = NULL;
-        }
-            
         if(two_pass)
         {
             working_directory->remove("twopass.log");
@@ -1259,8 +1484,7 @@ void DVDTranscodeThread::wipeClean()
     //  partially created
     //
     cleanUp();
-    QDir d("stupid");
-    d.remove(QString("%1.avi").arg(destination_file_string));
+    QDir::current().remove(QString("%1.avi").arg(destination_file_string));
 }
 
 DVDTranscodeThread::~DVDTranscodeThread()
@@ -1273,9 +1497,4 @@ DVDTranscodeThread::~DVDTranscodeThread()
     {
         delete tc_process;
     }
-    if(ripfile)
-    {
-        delete ripfile;
-    }
 }
-
