@@ -305,6 +305,58 @@ Nästa skärm kommer att vara tom, använd Escape för att komma tillbaka till m
         <source>Tracks from current Year</source>
         <translation>Spår från aktuellt år</translation>
     </message>
+    <message>
+        <source>Search</source>
+        <translation>Sök</translation>
+    </message>
+    <message>
+        <source>From CD</source>
+        <translation>Från CD</translation>
+    </message>
+    <message>
+        <source>Change Filter</source>
+        <translation>Ändra filter</translation>
+    </message>
+    <message>
+        <source>Update Playlist Options</source>
+        <translation>Uppdatera spellistinställningar</translation>
+    </message>
+    <message>
+        <source>Replace</source>
+        <translation>Ersätt</translation>
+    </message>
+    <message>
+        <source>Insert after current track</source>
+        <translation>Infoga efter aktuellt spår</translation>
+    </message>
+    <message>
+        <source>Append to end</source>
+        <translation>Lägg till slutet</translation>
+    </message>
+    <message>
+        <source>Continue playing current track</source>
+        <translation>Fortsätt spela upp aktuellt spår</translation>
+    </message>
+    <message>
+        <source>Play first track</source>
+        <translation>Spela första spår</translation>
+    </message>
+    <message>
+        <source>Play first new track</source>
+        <translation>Spela första nya spår</translation>
+    </message>
+    <message>
+        <source>Remove Duplicates</source>
+        <translation>Ta bort dubbletter</translation>
+    </message>
+    <message>
+        <source>1 Shuffle: Album</source>
+        <translation>1 Ordning: Album</translation>
+    </message>
+    <message>
+        <source>Shuffle: Album</source>
+        <translation>Ordning: Album</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -340,10 +392,6 @@ Nästa skärm kommer att vara tom, använd Escape för att komma tillbaka till m
         <source>Audio device</source>
         <translation>Ljudenhet</translation>
     </message>
-    <message>
-        <source>Audio Device used for playback.</source>
-        <translation>Ljudenhet som används för avspelning.</translation>
-    </message>
     <message>
         <source>CD device</source>
         <translation>CD-enhet</translation>
@@ -424,10 +472,6 @@ Nästa skärm kommer att vara tom, använd Escape för att komma tillbaka till m
         <source>Token separator</source>
         <translation>Separator</translation>
     </message>
-    <message>
-        <source> - </source>
-        <translation>-</translation>
-    </message>
     <message>
         <source>Filename tokens will be separated by this string.</source>
         <translation>De olika delarna av ett filnamn separeras med detta tecken.</translation>
@@ -688,18 +732,10 @@ Nästa skärm kommer att vara tom, använd Escape för att komma tillbaka till m
         <source>Missing database entry: %1</source>
         <translation>Saknad databasrad: %1</translation>
     </message>
-    <message>
-        <source> ~ </source>
-        <translation> ~ </translation>
-    </message>
     <message>
         <source>Ooops</source>
         <translation>Ooops</translation>
     </message>
-    <message>
-        <source>%1 ~ %2</source>
-        <translation>%1 ~ %2</translation>
-    </message>
     <message>
         <source>Not Initialized</source>
         <translation>Ej initierad</translation>
@@ -708,10 +744,6 @@ Nästa skärm kommer att vara tom, använd Escape för att komma tillbaka till m
         <source>oops</source>
         <translation>oops</translation>
     </message>
-    <message>
-        <source>,%1</source>
-        <translation>,%1</translation>
-    </message>
     <message>
         <source>All My Playlists</source>
         <translation>Alla mina spellistor</translation>
@@ -748,10 +780,6 @@ Nästa skärm kommer att vara tom, använd Escape för att komma tillbaka till m
         <source>If set, the MP3 encoder will use variable bitrates (VBR) except for the low quality setting. The Ogg encoder will always use variable bitrates.</source>
         <translation>MP3-kodaren kommer att använda variabel bithastighet (VBR) förutom då lägsta kvaliteten väljs. Ogg-kodaren använder alltid variabel bithastighet.</translation>
     </message>
-    <message>
-        <source>AlbumArt</source>
-        <translation>AlbumArt</translation>
-    </message>
     <message>
         <source>CD Ripper Settings (part 2)</source>
         <translation>Inställningar för CD-kopiering (del 2)</translation>
@@ -768,10 +796,6 @@ Nästa skärm kommer att vara tom, använd Escape för att komma tillbaka till m
         <source>CD-Writer Device</source>
         <translation>CD-brännarenhet</translation>
     </message>
-    <message>
-        <source>Select the SCSI Device for CD Writing.  If your IDE device is not present, try adding hdd(or hdc/hdb)=ide-scsi to your boot options</source>
-        <translation>Välj en SCSI-enhet för CD-bränning. Om idin IDE-enhet inte finns tillgänglig, testa lägga till hdd (eller hdc/hdb)=ide-scsi till dina startinstälningar</translation>
-    </message>
     <message>
         <source>Disk Size</source>
         <translation>Skivstorlek</translation>
@@ -800,26 +824,6 @@ Nästa skärm kommer att vara tom, använd Escape för att komma tillbaka till m
         <source>Auto</source>
         <translation>Audo</translation>
     </message>
-    <message>
-        <source>1x</source>
-        <translation>1x</translation>
-    </message>
-    <message>
-        <source>2x</source>
-        <translation>2x</translation>
-    </message>
-    <message>
-        <source>4x</source>
-        <translation>4x</translation>
-    </message>
-    <message>
-        <source>8x</source>
-        <translation>8x</translation>
-    </message>
-    <message>
-        <source>16x</source>
-        <translation>16x</translation>
-    </message>
     <message>
         <source>CD Writer speed. Auto will use the recomended speed.</source>
         <translation>CD-bränningshastighet. Auto använder rekommenderad hastighet.</translation>
@@ -844,10 +848,6 @@ Nästa skärm kommer att vara tom, använd Escape för att komma tillbaka till m
         <source>CD Recording Settings</source>
         <translation>CD-bränningsinställningar</translation>
     </message>
-    <message>
-        <source>Artists</source>
-        <translation>Artister</translation>
-    </message>
     <message>
         <source>Creating CD File System</source>
         <translation>Skapar filsystem för CD</translation>
@@ -861,14 +861,58 @@ Nästa skärm kommer att vara tom, använd Escape för att komma tillbaka till m
         <translation>?</translation>
     </message>
     <message>
-        <source>Order in which to sort the Music Tree. Possible values are a space-separated list of genre, splitartist, artist, album, and title OR the keyword &quot;directory&quot; to indicate that the onscreen tree mirrors the filesystem.</source>
+        <source>Track %1</source>
+        <translation>Spår %1</translation>
+    </message>
+    <message>
+        <source>Order in which to sort the Music Tree. Possible values are a space-separated list of genre, splitartist, splitartist1, artist, album, and title OR the keyword &quot;directory&quot; to indicate that the onscreen tree mirrors the filesystem.</source>
         <translation>Den ordning som trädet för musikval sorteras i. Möjliga värden är:
-* Mellanslagsseparerad lista med &apos;genre&apos;, &apos;splitartist&apos;, &apos;artist&apos;, &apos;album&apos; och &apos;title&apos;
+* Mellanslagsseparerad lista med &apos;genre&apos;, &apos;splitartist&apos;, &apos;splitartist1&apos;, &apos;artist&apos;, &apos;album&apos; och &apos;title&apos;
 * &apos;directory&apos; (=katalog), vilket betyder att trädet speglar den faktiska katalogstrukturen.</translation>
     </message>
     <message>
-        <source>CD: %1 ~ %2 - %3</source>
-        <translation>CD: %1 ~ %2 - %3</translation>
+        <source>Automatically play CDs</source>
+        <translation>Spela CD-skivor automatiskt</translation>
+    </message>
+    <message>
+        <source>Automatically put a new CD on the playlist and start playing the CD.</source>
+        <translation>Lägg automatiskt ny CD-skiva i spellistan och börja spela.</translation>
+    </message>
+    <message>
+        <source>Select the SCSI or IDE Device for CD Writing.</source>
+        <translation>Välj SCSI- eller IDE-enhet för CD-bränning.</translation>
+    </message>
+    <message>
+        <source>Scanning music files</source>
+        <translation>Letar efter musikfiler</translation>
+    </message>
+    <message>
+        <source>Rebuilding music tree</source>
+        <translation>Återuppbygger musikträd</translation>
+    </message>
+    <message>
+        <source>Only Import new music.</source>
+        <translation>Importera endast ny musik.</translation>
+    </message>
+    <message>
+        <source>Checks the database for duplicates when importing/ripping CDs.</source>
+        <translation>Letar efter dubbletter i databasen vid import/inläsning av CD.</translation>
+    </message>
+    <message>
+        <source>Loading Music</source>
+        <translation>Laddar musik</translation>
+    </message>
+    <message>
+        <source>default</source>
+        <translation>förvald</translation>
+    </message>
+    <message>
+        <source>Audio Device used for playback. &apos;default&apos; will use the device specified in MythTV</source>
+        <translation>Ljudenhet för uppspelning. &apos;förvald&apos; använder enheten angiven i MythTV</translation>
+    </message>
+    <message>
+        <source>Unknown Title</source>
+        <translation>Okänd titel</translation>
     </message>
 </context>
 <context>
@@ -912,7 +956,7 @@ Nästa skärm kommer att vara tom, använd Escape för att komma tillbaka till m
     <message>
         <source>Importing CD:
 </source>
-        <translation>Importing CD:
+        <translation>Importerar CD:
 </translation>
     </message>
     <message>
@@ -945,6 +989,14 @@ Nästa skärm kommer att vara tom, använd Escape för att komma tillbaka till m
         <source>Length</source>
         <translation>Längd</translation>
     </message>
+    <message>
+        <source>Quality: </source>
+        <translation>Kvalitet: </translation>
+    </message>
+    <message>
+        <source>Importing </source>
+        <translation>Importerar </translation>
+    </message>
 </context>
 <context>
     <name>SmartPLCriteriaRow</name>
