@@ -1,5 +1,25 @@
-#include <stdio.h>
-#include <string.h>
+// ANSI C includes
+#include <cstdio>
+#include <cstring>
+
+// Unix C includes
+#include <unistd.h>
+#include <sys/stat.h>
+#include <sys/types.h>
+#include <fcntl.h>
+
+// Linux C includes
+#include <cdaudio.h>
+extern "C" {
+#include <cdda_interface.h>
+#include <cdda_paranoia.h>
+}
+
+// C++ includes
+#include <iostream>
+using namespace std;
+
+// Qt includes
 #include <qapplication.h>
 #include <qdir.h>
 #include <qdialog.h>
@@ -12,19 +32,14 @@
 #include <qvbox.h>
 #include <qprogressbar.h>
 #include <qradiobutton.h>
-#include <iostream>
 
-#include <unistd.h>
-#include <sys/stat.h>
-#include <sys/types.h>
-#include <fcntl.h>
-#include <cdaudio.h>
-
-extern "C" {
-#include <cdda_interface.h>
-#include <cdda_paranoia.h>
-}
+// MythTV plugin includes
+#include <mythtv/mythcontext.h>
+#include <mythtv/mythdbcon.h>
+#include <mythtv/mythwidgets.h>
+#include <mythtv/lcddevice.h>
 
+// MythMusic includes
 #include "cdrip.h"
 #include "cddecoder.h"
 #include "encoder.h"
@@ -32,12 +47,6 @@ extern "C" {
 #include "lameencoder.h"
 #include "flacencoder.h"
 
-#include <mythtv/mythcontext.h>
-#include <mythtv/mythdbcon.h>
-#include <mythtv/mythwidgets.h>
-
-using namespace std;
-
 Ripper::Ripper(MythMainWindow *parent, const char *name)
       : MythDialog(parent, name)
 {
@@ -73,33 +82,16 @@ Ripper::Ripper(MythMainWindow *parent, const char *name)
     inst->setBackgroundOrigin(WindowOrigin);
     vbox->addWidget(inst);
 
-    QHBoxLayout *qualbox = new QHBoxLayout(vbox, 10);
-    qualitygroup = new MythButtonGroup(firstdiag);
-    qualitygroup->setFrameStyle(QFrame::NoFrame);
-    qualitygroup->hide();
+    QLabel *quality = new QLabel(tr("Quality: "), firstdiag);
+    quality->setBackgroundOrigin(WindowOrigin);
 
-    QRadioButton *lowquality = new QRadioButton(tr("Low"), firstdiag);
-    lowquality->setBackgroundOrigin(WindowOrigin);
-    qualbox->addWidget(lowquality);
-    qualitygroup->insert(lowquality);
-
-    QRadioButton *mediumquality = new QRadioButton(tr("Medium"), firstdiag);
-    mediumquality->setBackgroundOrigin(WindowOrigin);
-    qualbox->addWidget(mediumquality);
-    qualitygroup->insert(mediumquality);
-
-    QRadioButton *highquality = new QRadioButton(tr("High"), firstdiag);
-    highquality->setBackgroundOrigin(WindowOrigin);
-    qualbox->addWidget(highquality);
-    qualitygroup->insert(highquality);
-
-    QRadioButton *perfectflac = new QRadioButton(tr("Perfect"), firstdiag);
-    perfectflac->setBackgroundOrigin(WindowOrigin);
-    qualbox->addWidget(perfectflac);
-    qualitygroup->insert(perfectflac);
-
-    qualitygroup->setRadioButtonExclusive(true);
-    qualitygroup->setButton(gContext->GetNumSetting("DefaultRipQuality", 1));
+    qualchooser = new MythComboBox(false, firstdiag);
+    qualchooser->insertItem(tr("Low"));
+    qualchooser->insertItem(tr("Medium"));
+    qualchooser->insertItem(tr("High"));
+    qualchooser->insertItem(tr("Perfect"));
+    qualchooser->setCurrentItem(gContext->GetNumSetting("DefaultRipQuality", 1));
+    qualchooser->setMaximumWidth(screenwidth / 2);
 
     QGridLayout *grid = new QGridLayout(vbox, 1, 1, 20);
     
@@ -112,8 +104,9 @@ Ripper::Ripper(MythMainWindow *parent, const char *name)
     // which totally messes up the rest of the page.
     artistedit->setMaximumWidth((int)(0.7 * screenwidth));
 
-    fillComboBox(*artistedit, "artist");
-
+    QStringList strlist = Metadata::fillFieldList("artist");
+    artistedit->insertStringList(strlist);
+    
     QLabel *albuml = new QLabel(tr("Album: "), firstdiag);
     albuml->setBackgroundOrigin(WindowOrigin);
     albumedit = new MythLineEdit(firstdiag);
@@ -122,7 +115,8 @@ Ripper::Ripper(MythMainWindow *parent, const char *name)
     QLabel *genrelabel = new QLabel(tr("Genre: "), firstdiag);
     genrelabel->setBackgroundOrigin(WindowOrigin);
     genreedit = new MythComboBox(true, firstdiag);
-    fillComboBox (*genreedit, "genre");
+    strlist = Metadata::fillFieldList("genre");
+    genreedit->insertStringList(strlist);
 
 
     compilation = new MythCheckBox(firstdiag);
@@ -136,17 +130,19 @@ Ripper::Ripper(MythMainWindow *parent, const char *name)
     connect(switchtitleartist, SIGNAL(clicked()), this, SLOT(switchTitlesAndArtists())); 
     
 
-    grid->addMultiCellWidget(artistl, 0, 0, 0, 0);
-    grid->addMultiCellWidget(artistedit,  0, 0, 1, 2);
-    grid->addMultiCellWidget(albuml, 1, 1, 0, 0);
-    grid->addMultiCellWidget(albumedit,  1, 1, 1, 2);
-    grid->addMultiCellWidget(genrelabel, 2, 2, 0, 0);
-    grid->addMultiCellWidget(genreedit, 2, 2, 1, 2);
-    grid->addMultiCellWidget(compilation, 3, 3, 0, 0);
-    grid->addMultiCellWidget(switchtitleartist, 3, 3, 1, 2);
+    grid->addMultiCellWidget(quality, 0, 0, 0, 0);
+    grid->addMultiCellWidget(qualchooser,  0, 0, 1, 2);
+    grid->addMultiCellWidget(artistl, 1, 1, 0, 0);
+    grid->addMultiCellWidget(artistedit,  1, 1, 1, 2);
+    grid->addMultiCellWidget(albuml, 2, 2, 0, 0);
+    grid->addMultiCellWidget(albumedit,  2, 2, 1, 2);
+    grid->addMultiCellWidget(genrelabel, 3, 3, 0, 0);
+    grid->addMultiCellWidget(genreedit, 3, 3, 1, 2);
+    grid->addMultiCellWidget(compilation, 4, 4, 0, 0);
+    grid->addMultiCellWidget(switchtitleartist, 4, 4, 1, 2);
 
     table = new MythTable(firstdiag);
-    grid->addMultiCellWidget(table, 4, 4, 0, 2);
+    grid->addMultiCellWidget(table, 5, 5, 0, 2);
     table->setNumCols(4);
     table->setLeftMargin(0);
     table->setNumRows(1);
@@ -167,11 +163,11 @@ Ripper::Ripper(MythMainWindow *parent, const char *name)
     bool iscompilation = false;
 
     CdDecoder *decoder = new CdDecoder("cda", NULL, NULL, NULL);
-
+    bool newTune = true;
+    int row = 0;
     if (decoder)
     {
 
-        int row = 0;
         QString label;
         int length, min, sec;
         Metadata *track;
@@ -201,24 +197,31 @@ Ripper::Ripper(MythMainWindow *parent, const char *name)
                 }
 
                 length = track->Length() / 1000;
-                min = length / 60;
-                sec = length % 60;
-                
-                table->setNumRows(row + 1);
-                
-                table->setRowHeight(row, (int)(30 * hmult));
-                
-                label.sprintf("%d", trackno + 1);
-                table->setText(row, 0, label);
-                
-                table->setText(row, 1, track->Title());
-                
-                table->setText(row, 2, track->Artist());
-                
-                label.sprintf("%02d:%02d", min, sec);
-                table->setText(row, 3, label);
-                
-                row++;
+
+                QString title = track->Title();
+                newTune = isNewTune(artistname, albumname, title);
+
+                if (newTune)
+                {
+                    min = length / 60;
+                    sec = length % 60;
+
+                    table->setNumRows(row + 1);
+
+                    table->setRowHeight(row, (int)(30 * hmult));
+
+                    label.sprintf("%d", trackno + 1);
+                    table->setText(row, 0, label);
+
+                    table->setText(row, 1, track->Title());
+
+                    table->setText(row, 2, track->Artist());
+
+                    label.sprintf("%02d:%02d", min, sec);
+                    table->setText(row, 3, label);
+
+                    row++;
+                }
                 delete track;
             }
         }
@@ -266,15 +269,55 @@ Ripper::Ripper(MythMainWindow *parent, const char *name)
 
 
     MythPushButton *ripit = new MythPushButton(tr("Import this CD"), firstdiag);
+    ripit->setFocus ();
     vbox->addWidget(ripit);
-
-    connect(ripit, SIGNAL(clicked()), this, SLOT(ripthedisc())); 
+    if (row != 0)
+    {
+        connect(ripit, SIGNAL(clicked()), this, SLOT(ripthedisc())); 
+    }
 }
 
 Ripper::~Ripper(void)
 {   
 }       
 
+bool Ripper::isNewTune(QString& artist, QString& album, QString& title)
+{
+    if (gContext->GetNumSetting("OnlyImportNewMusic",1))
+    {
+        MSqlQuery query(MSqlQuery::InitCon());
+        QString queryString("SELECT filename, artist_name, album_name, name, song_id "
+                            "FROM music_songs "
+                            "LEFT JOIN music_artists ON music_songs.artist_id=music_artists.artist_id "
+                            "LEFT JOIN music_albums ON music_songs.album_id=music_albums.album_id "
+                            "WHERE artist_name REGEXP \'");      
+        QString token = artist;
+        token.replace(QRegExp("(/|\\\\|:|\'|\\,|\\!|\\(|\\)|\"|\\?|\\|)"), QString("."));
+      
+        queryString += token + "\' AND " + "album_name REGEXP \'";
+        token = album;
+        token.replace(QRegExp("(/|\\\\|:|\'|\\,|\\!|\\(|\\)|\"|\\?|\\|)"), QString("."));
+        queryString += token + "\' AND " + "name    REGEXP \'";
+        token = title;
+        token.replace(QRegExp("(/|\\\\|:|\'|\\,|\\!|\\(|\\)|\"|\\?|\\|)"), QString("."));
+        queryString += token + "\' ORDER BY artist_name, album_name, name, song_id, filename";      
+        query.prepare(queryString);
+        
+        bool has_entries = true;     
+        if (!query.exec() || !query.isActive())
+        {
+            MythContext::DBError("Search music database", query);
+            has_entries = false;
+        }
+        if (query.numRowsAffected() > 0)
+        {
+            return false;
+        }
+    }       
+    return true;
+}
+
+
 QSizePolicy Ripper::sizePolicy(void)
 {
     return QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
@@ -360,12 +403,16 @@ void Ripper::compilationChanged(bool state)
         {
             data = decoder->getMetadata(trackno);
 
-            // Make metadata appear to be just a normal track.
-            data->setCompilationArtist("");
-            data->setArtist(artistname);
-            data->setCompilation(false);
-            decoder->commitMetadata(data);
-            delete data;
+            //  Metadata will be NULL for non-audio tracks
+            if(data)
+            {
+                // Make metadata appear to be just a normal track.
+                data->setCompilationArtist("");
+                data->setArtist(artistname);
+                data->setCompilation(false);
+                decoder->commitMetadata(data);
+                delete data;
+            }
         }
         
         // Visual updates
@@ -379,12 +426,16 @@ void Ripper::compilationChanged(bool state)
         {
             data = decoder->getMetadata(trackno);
 
-            // Make metadata appear to be just a normal track.
-            data->setCompilationArtist(artistname);
-            data->setArtist(table->text(trackno - 1, 2));
-            data->setCompilation(true);
-            decoder->commitMetadata(data);
-            delete data;
+            //  Metadata will be NULL for non-audio tracks
+            if(data)
+            {
+                // Make metadata appear to be just a normal track.
+                data->setCompilationArtist(artistname);
+                data->setArtist(table->text(trackno - 1, 2));
+                data->setCompilation(true);
+                decoder->commitMetadata(data);
+                delete data;
+            }
         }
 
         // Visual updates
@@ -478,31 +529,6 @@ void Ripper::switchTitlesAndArtists()
     delete decoder;
 }
 
-void Ripper::fillComboBox(MythComboBox &box, const QString &db_column)
-{
-    QString querystr = QString("SELECT DISTINCT %1 FROM musicmetadata;")
-                               .arg(db_column);
-      
-    MSqlQuery query(MSqlQuery::InitCon());
-    query.exec(querystr);
-   
-    QValueList<QString> list;
-   
-    if (query.isActive() && query.size() > 0)
-    { 
-        while (query.next())
-        {
-            list.push_front(query.value(0).toString());
-        }
-    }
-   
-    QStringList strlist(list);
-   
-    strlist.sort();
-   
-    box.insertStringList(strlist);
-}
-
 void Ripper::handleFileTokens(QString &filename, Metadata *track)
 {
     QString original = filename;
@@ -536,7 +562,7 @@ void Ripper::handleFileTokens(QString &filename, Metadata *track)
             if (no_ws)
                 filename.replace(rx_ws, "_");
 
-            mkdir(filename, 0775);
+            mkdir(filename.local8Bit(), 0775);
         }
     }
 
@@ -598,6 +624,33 @@ void Ripper::reject()
     done(Rejected);
 }
 
+static long int getSectorCount (QString &cddevice, int tracknum)
+{
+    cdrom_drive *device = cdda_identify(cddevice.ascii(), 0, NULL);
+
+    if (!device)
+        return -1;
+
+    if (cdda_open(device))
+    {
+        cdda_close(device);
+        return -1;
+    }
+
+    // we only care about audio tracks
+    if (cdda_track_audiop (device, tracknum))
+    {
+        cdda_verbose_set(device, CDDA_MESSAGE_FORGETIT, CDDA_MESSAGE_FORGETIT);
+        long int start = cdda_track_firstsector(device, tracknum);
+        long int end   = cdda_track_lastsector( device, tracknum);
+        cdda_close(device);
+        return end - start + 1;        
+    }
+
+    cdda_close(device);
+    return 0;
+}
+
 void Ripper::ripthedisc(void)
 {
     firstdiag->hide();
@@ -625,7 +678,7 @@ void Ripper::ripthedisc(void)
     overall->setBackgroundOrigin(WindowOrigin);
     overall->setProgress(0);
     vb->addWidget(overall);
-    
+
     statusline = new QLabel(" ", newdiag);
     statusline->setBackgroundOrigin(WindowOrigin);
     statusline->setAlignment(AlignAuto | AlignVCenter | ExpandTabs | WordBreak);
@@ -644,7 +697,7 @@ void Ripper::ripthedisc(void)
     QString textstatus;
     QString cddevice = gContext->GetSetting("CDDevice");
     QString encodertype = gContext->GetSetting("EncoderType");
-    int encodequal = qualitygroup->id(qualitygroup->selected());
+    int encodequal = qualchooser->currentItem();
     bool mp3usevbr = gContext->GetNumSetting("Mp3UseVBR", 0);
 
     CdDecoder *decoder = new CdDecoder("cda", NULL, NULL, NULL);
@@ -654,6 +707,23 @@ void Ripper::ripthedisc(void)
     if (!musicdir.endsWith("/"))
         musicdir += "/";
 
+    totalSectors = 0;
+    totalSectorsDone = 0;
+    for (int trackno = 0; trackno < decoder->getNumTracks(); trackno++)
+    {
+        totalSectors += getSectorCount (cddevice, trackno + 1);
+    }
+    overall->setTotalSteps (totalSectors);
+
+    if (class LCD * lcd = LCD::Get()) 
+    {
+        QString lcd_tots = tr("Importing ") + artistname + " - " + albumname;
+        QPtrList<LCDTextItem> textItems;
+        textItems.setAutoDelete(true);
+        textItems.append(new LCDTextItem(1, ALIGN_CENTERED, lcd_tots, "Generic", false));
+        lcd->switchToGeneric(&textItems);
+    }
+
     for (int trackno = 0; trackno < decoder->getNumTracks(); trackno++)
     {
         Encoder *encoder;
@@ -718,7 +788,6 @@ void Ripper::ripthedisc(void)
             // Set the flag to show that we have ripped new files
             somethingwasripped = true;
 
-            overall->setProgress(trackno + 1);
             qApp->processEvents();
 
             delete encoder;
@@ -734,7 +803,7 @@ void Ripper::ripthedisc(void)
 
     if (!PostRipCDScript.isEmpty()) 
     {
-        VERBOSE(VB_ALL, QString("PostCDRipScript: %1").arg(PostRipCDScript));
+        VERBOSE(VB_IMPORTANT, QString("PostCDRipScript: %1").arg(PostRipCDScript));
         pid_t child = fork();
         if (child < 0)
         {
@@ -821,11 +890,18 @@ int Ripper::ripTrack(QString &cddevice, Encoder *encoder, int tracknum)
         if (every15 <= 0) 
         {
             every15 = 15;
-            current->setProgress(curpos - start);
+            current->setProgress(curpos - start);           
+            overall->setProgress(totalSectorsDone + (curpos - start));
+            if (class LCD * lcd = LCD::Get()) 
+            {
+                float fProgress = (float)(totalSectorsDone + (curpos - start))/totalSectors;
+                lcd->setGenericProgress(fProgress);
+            }
             qApp->processEvents();
         }
     }
 
+    totalSectorsDone += end - start + 1;
     current->setProgress(end);
     qApp->processEvents();
         
