@@ -11,6 +11,7 @@
 #include <qstringlist.h>
 #include <qprocess.h>
 #include <qapplication.h>
+#include <mythtv/util.h>
 
 // General Settings
 
@@ -27,8 +28,9 @@ static HostLineEdit *SetMusicDirectory()
 
 static HostComboBox *MusicAudioDevice()
 {
-    HostComboBox *gc = new HostComboBox("AudioDevice", true);
+    HostComboBox *gc = new HostComboBox("MusicAudioDevice", true);
     gc->setLabel(QObject::tr("Audio device"));
+    gc->addSelection(QObject::tr("default"), "default");
     QDir dev("/dev", "dsp*", QDir::Name, QDir::System);
     gc->fillSelectionsFromDir(dev);
     dev.setNameFilter("adsp*");
@@ -39,7 +41,7 @@ static HostComboBox *MusicAudioDevice()
     gc->fillSelectionsFromDir(dev);
     dev.setNameFilter("adsp*");
     gc->fillSelectionsFromDir(dev);
-    gc->setHelpText(QObject::tr("Audio Device used for playback."));
+    gc->setHelpText(QObject::tr("Audio Device used for playback. 'default' will use the device specified in MythTV"));
     return gc;
 };
 
@@ -68,8 +70,8 @@ static HostLineEdit *TreeLevels()
     gc->setValue("splitartist artist album title");
     gc->setHelpText(QObject::tr("Order in which to sort the Music "
                     "Tree. Possible values are a space-separated list of "
-                    "genre, splitartist, artist, album, and title OR the "
-                    "keyword \"directory\" to indicate that "
+                    "genre, splitartist, splitartist1, artist, album, and "
+                    "title OR the keyword \"directory\" to indicate that "
                     "the onscreen tree mirrors the filesystem."));
     return gc;
 };
@@ -107,6 +109,15 @@ static HostCheckBox *IgnoreID3Tags()
     return gc;
 };
 
+static HostCheckBox *OnlyImportNewMusic()
+{
+    HostCheckBox *gc = new HostCheckBox("OnlyImportNewMusic");
+    gc->setLabel(QObject::tr("Only Import new music."));
+    gc->setValue(false);
+    gc->setHelpText(QObject::tr("Checks the database for duplicates when importing/ripping CDs."));
+    return gc;
+};
+
 static HostCheckBox *AutoLookupCD()
 {
     HostCheckBox *gc = new HostCheckBox("AutoLookupCD");
@@ -118,6 +129,16 @@ static HostCheckBox *AutoLookupCD()
     return gc;
 };
 
+static HostCheckBox *AutoPlayCD()
+{
+    HostCheckBox *gc = new HostCheckBox("AutoPlayCD");
+    gc->setLabel(QObject::tr("Automatically play CDs"));
+    gc->setValue(false);
+    gc->setHelpText(QObject::tr("Automatically put a new CD on the "
+                                "playlist and start playing the CD."));
+    return gc;
+};
+
 static HostCheckBox *KeyboardAccelerators()
 {
     HostCheckBox *gc = new HostCheckBox("KeyboardAccelerators");
@@ -182,7 +203,7 @@ static HostLineEdit *TagSeparator()
 {
     HostLineEdit *gc = new HostLineEdit("TagSeparator");
     gc->setLabel(QObject::tr("Token separator"));
-    gc->setValue(QObject::tr(" - "));
+    gc->setValue(" - ");
     gc->setHelpText(QObject::tr("Filename tokens will be separated by "
                     "this string."));
     return gc;
@@ -359,19 +380,12 @@ static HostLineEdit *VisualizationMode()
 {
     HostLineEdit *gc = new HostLineEdit("VisualMode");
     gc->setLabel(QObject::tr("Visualizations"));
-    gc->setValue(QObject::tr("Random"));
-    gc->setHelpText(QObject::tr("List of visualizations to use during playback."
-                    " Possible values are space-separated list of ") +
-                    QObject::tr("Random") + ", " + 
-                    QObject::tr("MonoScope") + ", " + 
-                    QObject::tr("StereoScope") + ", " + 
-                    QObject::tr("Spectrum") + ", " + 
-                    QObject::tr("BumpScope") + ", " + 
-                    QObject::tr("Goom") + ", " + 
-                    QObject::tr("Synaesthesia") + ", " +
-                    QObject::tr("AlbumArt") + ", " +
-                    QObject::tr("Gears") + ", " + QObject::tr("and") + " " + 
-                    QObject::tr("Blank"));
+    gc->setValue("Random");
+    gc->setHelpText(QObject::tr("List of visualizations to use during playback. "
+                    "Possible values are space-separated list of ") + "Random, "
+                    "MonoScope, StereoScope, Spectrum, BumpScope, Goom, "
+                    "Synaesthesia, AlbumArt, Gears, Squares " + QObject::tr("and") +
+                    " Blank");
     return gc;
 };
 
@@ -390,55 +404,72 @@ static HostComboBox *CDWriterDevice()
 {
     HostComboBox *gc = new HostComboBox("CDWriterDevice");
 
-    QStringList args;
-    QStringList result;
+    QString argadd[3]  = { "", "-dev=ATA", "-dev=ATAPI" };
+    QString prepend[3] = { "", "ATA:", "ATAPI:" };
 
-    args = "cdrecord";
-    args += "--scanbus";
-
-    QProcess proc(args);
-
-    if (proc.start())
+    for (int i = 0; i < 3; i++)
     {
-        while (1)
+        QStringList args;
+        QStringList result;
+
+        args = "cdrecord";
+        args += "--scanbus";
+
+        if (argadd[i].length() > 1)
+            args += argadd[i];
+
+        QProcess proc(args);
+
+        MythTimer totaltimer;
+    
+        if (proc.start())
         {
-            while (proc.canReadLineStdout())
-                result += proc.readLineStdout();
-            if (proc.isRunning())
+            totaltimer.start();
+
+            while (1)
             {
-                qApp->processEvents();
-                usleep(10000);
+                while (proc.canReadLineStdout())
+                    result += proc.readLineStdout();
+                if (proc.isRunning())
+                {
+                    qApp->processEvents();
+                    usleep(10000);
+                }
+                else
+                {
+                    if (!proc.normalExit())
+                        cerr << "Failed to run 'cdrecord --scanbus'\n";
+                    break;
+                }
+
+                if (totaltimer.elapsed() > 1500)
+                    proc.kill();
             }
-            else
+        }
+        else
+            cerr << "Failed to run 'cdrecord --scanbus'\n";
+
+        while (proc.canReadLineStdout())
+            result += proc.readLineStdout();
+
+        for (QStringList::Iterator it = result.begin(); it != result.end();
+             ++it)
+        {
+            QString line = *it;
+            if (line.length() > 12)
             {
-                if (!proc.normalExit())
-                    cerr << "Failed to run 'cdrecord --scanbus'\n";
-                break;
-            }
-        }
-    }
-    else
-        cerr << "Failed to run 'cdrecord --scanbus'\n";
-
-    while (proc.canReadLineStdout())
-        result += proc.readLineStdout();
-
-    for (QStringList::Iterator it = result.begin(); it != result.end();
-         ++it)
-    {
-        QString line = *it;
-        if (line.length() > 12)
-        {
-            if (line[10] == ')' && line[12] != '*')
-            {
-                gc->addSelection(line.mid(24, 16), line.mid(1, 5));
+                if (line[10] == ')' && line[12] != '*')
+                {
+                    gc->addSelection(line.mid(24, 16), prepend[i] + 
+                                                       line.mid(1, 5));
+cout << "adding: " << prepend[i] + line.mid(1, 5) << " -- " << line.mid(24, 16) << endl;
+                }
             }
         }
     }
+    
     gc->setLabel(QObject::tr("CD-Writer Device"));
-    gc->setHelpText(QObject::tr("Select the SCSI Device for CD Writing.  If "
-                    "your IDE device is not present, try adding "
-                    "hdd(or hdc/hdb)=ide-scsi to your boot options"));
+    gc->setHelpText(QObject::tr("Select the SCSI or IDE Device for CD Writing."));
     return gc;
 };
 
@@ -466,11 +497,11 @@ static HostComboBox *CDWriteSpeed()
     HostComboBox *gc = new HostComboBox("CDWriteSpeed");
     gc->setLabel(QObject::tr("CD Write Speed"));
     gc->addSelection(QObject::tr("Auto"), "0");
-    gc->addSelection(QObject::tr("1x"), "1");
-    gc->addSelection(QObject::tr("2x"), "2");
-    gc->addSelection(QObject::tr("4x"), "4");
-    gc->addSelection(QObject::tr("8x"), "8");
-    gc->addSelection(QObject::tr("16x"), "16");
+    gc->addSelection("1x", "1");
+    gc->addSelection("2x", "2");
+    gc->addSelection("4x", "4");
+    gc->addSelection("8x", "8");
+    gc->addSelection("16x", "16");
     gc->setHelpText(QObject::tr("CD Writer speed. Auto will use the recomended "
                     "speed."));
     return gc;
@@ -498,6 +529,7 @@ MusicGeneralSettings::MusicGeneralSettings()
     general->addChild(NonID3FileNameFormat());
     general->addChild(IgnoreID3Tags());
     general->addChild(AutoLookupCD());
+    general->addChild(AutoPlayCD());
     general->addChild(KeyboardAccelerators());
     addChild(general);
 
@@ -546,6 +578,7 @@ MusicRipperSettings::MusicRipperSettings()
     rippersettings->addChild(NoWhitespace());
     rippersettings->addChild(PostCDRipScript());
     rippersettings->addChild(EjectCD());
+    rippersettings->addChild(OnlyImportNewMusic());
     addChild(rippersettings);
 
     VerticalConfigurationGroup* encodersettings = new VerticalConfigurationGroup(false);
