@@ -549,7 +549,7 @@ void PlaybackBoxMusic::allTracks()
         return;
 
    closePlaylistPopup();
-   updatePlaylistFromQuickPlaylist("ORDER BY artist_name, album_name, track");
+   updatePlaylistFromQuickPlaylist("ORDER BY music_artists.artist_name, album_name, track");
 }
 
 void PlaybackBoxMusic::fromCD()
@@ -605,7 +605,7 @@ void PlaybackBoxMusic::byArtist()
         return;
 
     QString value = formattedFieldValue(curMeta->Artist().utf8());
-    QString whereClause = "WHERE artist_name = " + value +
+    QString whereClause = "WHERE music_artists.artist_name = " + value +
                           " ORDER BY album_name, track"; 
 
     closePlaylistPopup();
@@ -631,7 +631,7 @@ void PlaybackBoxMusic::byGenre()
 
     QString value = formattedFieldValue(curMeta->Genre().utf8()); 
     QString whereClause = "WHERE genre = " + value +
-                          " ORDER BY artist_name, album_name, track";   
+                          " ORDER BY music_artists.artist_name, album_name, track";   
     closePlaylistPopup();
     updatePlaylistFromQuickPlaylist(whereClause);
 }
@@ -642,8 +642,8 @@ void PlaybackBoxMusic::byYear()
         return;
 
     QString value = formattedFieldValue(curMeta->Year()); 
-    QString whereClause = "WHERE year = " + value + 
-                          " ORDER BY artist_name, album_name, track";
+    QString whereClause = "WHERE music_songs.year = " + value + 
+                          " ORDER BY music_artists.artist_name, album_name, track";
     closePlaylistPopup();
     updatePlaylistFromQuickPlaylist(whereClause);
 }
@@ -854,14 +854,16 @@ void PlaybackBoxMusic::occasionallyCheckCD()
         all_playlists->clearCDList();
         all_playlists->getActive()->ripOutAllCDTracksNow();
 
-        if(all_music->getCDTrackCount()) {
+        if(all_music->getCDTrackCount())
+        {
             visual_mode_timer->stop();
 
             all_playlists->getActive()->removeAllTracks();
             all_playlists->getActive()->fillSongsFromCD();
 
-            postUpdate();
         }
+
+            postUpdate();
     }
 
     if (scan_for_cd && !cd_reader_thread->running())
@@ -1093,9 +1095,12 @@ void PlaybackBoxMusic::play()
         input = new QFile(playfile);
     
     if (decoder && !decoder->factory()->supports(sourcename))
+    {
+        decoder->removeListener(this);
         decoder = 0;
+    }
 
-    if (!decoder) 
+    if (!decoder)
     {
         decoder = Decoder::create(sourcename, input, output);
 
@@ -1665,7 +1670,8 @@ void PlaybackBoxMusic::customEvent(QCustomEvent *event)
     {
         case OutputEvent::Playing:
         {
-            updateTrackInfo(curMeta);
+            if (curMeta)
+                updateTrackInfo(curMeta);
             statusString = tr("Playing stream.");
             break;
         }
