@@ -213,10 +213,6 @@
         <source>Packets In/Out/Lost/Late:             </source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Average Kbps In/Out: </source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Video</source>
         <translation type="unfinished"></translation>
@@ -249,10 +245,6 @@
         <source>Packets In/Out/Lost/Late: </source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Average Kbps In/Out:</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Volume</source>
         <translation type="unfinished"></translation>
@@ -293,6 +285,22 @@
         <source>Dial</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Playout Delay Min/Avg/Max:            </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Packets Lost by Peer:                 </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Packets Lost by Peer: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Playout Delay Min/Avg/Max: </source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -456,10 +464,6 @@
         <source>SIP Proxy Settings</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>SIP Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>VXML Settings</source>
         <translation type="unfinished"></translation>
@@ -532,5 +536,29 @@
         <source>Me</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Jitter Buffer (Audio Call)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Size of the playout buffer in ms for an audio call. </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Jitter Buffer (Video Call)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Size of the playout buffer in ms for a video call. This should be bigger than for an audio call because CPU usage causes jitter and to sync video &amp; audio.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>IP Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>AUDIO Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
