@@ -11,7 +11,7 @@
     </message>
     <message>
         <source>No Cover</source>
-        <translation>Pas d&apos;affiche</translation>
+        <translation type="obsolete">Pas d&apos;affiche</translation>
     </message>
     <message>
         <source>Done</source>
@@ -67,14 +67,6 @@
         <source>1 - Lowest</source>
         <translation>1 - Sévère</translation>
     </message>
-    <message>
-        <source>2</source>
-        <translation>2</translation>
-    </message>
-    <message>
-        <source>3</source>
-        <translation>3</translation>
-    </message>
     <message>
         <source>This is the &apos;level&apos; that MythVideo starts at. Any videos with a level at or below this will be shown in the list or while browsing by default. The Parental PIN should be set to limit changing of the default level.</source>
         <translation>C&apos;est le niveau à partir duquel MythVideo démarre. Toutes les vidéos avec un niveau inférieur ou égal à la valeur seront affiché dans la liste. Afin d&apos;empêcher le changement du niveau par défaut, le code parental doit être saisi !</translation>
@@ -103,21 +95,17 @@
         <source>If set, this will cause the Video List screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
         <translation>Si coché, l&apos;écran &apos;Liste des vidéos&apos; affichera tous les fichiers du répertoire MythVideo même s&apos;ils n&apos;ont pas été recherchés.</translation>
     </message>
-    <message>
-        <source>General Settings</source>
-        <translation>Configuration générale</translation>
-    </message>
     <message>
         <source>Player Settings</source>
         <translation>Configuration du lecteur</translation>
     </message>
     <message>
         <source>Parental Pin:</source>
-        <translation>Code parental:</translation>
+        <translation type="obsolete">Code parental:</translation>
     </message>
     <message>
         <source>No Cover</source>
-        <translation>Pas d&apos;affiche</translation>
+        <translation type="obsolete">Pas d&apos;affiche</translation>
     </message>
     <message>
         <source>Unknown</source>
@@ -129,7 +117,7 @@
     </message>
     <message>
         <source>Unknown Rating</source>
-        <translation>Tout public</translation>
+        <translation type="obsolete">Tout public</translation>
     </message>
     <message>
         <source>Default Player</source>
@@ -245,8 +233,100 @@
         <translation>La vue par défaut pour MythVideo. Les autres vues peuvent être atteintes à travers le menu popup accessible par la touche MENU</translation>
     </message>
     <message>
-        <source>videos</source>
-        <translation>videos</translation>
+        <source>Video Browser browses files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, this will cause the Video Browser screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video Gallery browses files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, this will cause the Video Gallery screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General Settings (1/2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General Settings (2/2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video List Loads Video Meta Data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set along with Browse Files, this will cause the Video List to load any known video metadata from the database. Turning this off can greatly  speed up how long it takes to load the Video List tree</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sorting ignores case</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, case is ignored when sorting entries in a view.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show folders for database views</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, sub folders of your video directory will be shown in supported views.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image cache size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This setting determines the number of images MythVideo will cache for views.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>^(The |A |An )</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished">tous</translation>
+    </message>
+    <message>
+        <source>Yes</source>
+        <translation type="unfinished">Oui</translation>
+    </message>
+    <message>
+        <source>No</source>
+        <translation type="unfinished">Non</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation type="unfinished">Année</translation>
+    </message>
+    <message>
+        <source>User Rating</source>
+        <translation type="unfinished">Notation</translation>
+    </message>
+    <message>
+        <source>Runtime</source>
+        <translation type="unfinished">Durée</translation>
+    </message>
+    <message>
+        <source>Filename</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video ID</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -480,11 +560,11 @@
     </message>
     <message>
         <source>No rating available.</source>
-        <translation>Pas de note disponible.</translation>
+        <translation type="obsolete">Pas de note disponible.</translation>
     </message>
     <message>
         <source>minutes</source>
-        <translation>minutes</translation>
+        <translation type="obsolete">minutes</translation>
     </message>
     <message>
         <source>Watch This Video</source>
@@ -527,7 +607,7 @@
     </message>
     <message>
         <source>Parental Pin:</source>
-        <translation>Code parental:</translation>
+        <translation type="obsolete">Code parental:</translation>
     </message>
 </context>
 <context>
@@ -542,7 +622,7 @@
     </message>
     <message>
         <source>Unknown</source>
-        <translation>Inconnu</translation>
+        <translation type="obsolete">Inconnu</translation>
     </message>
     <message>
         <source>minutes</source>
@@ -550,7 +630,7 @@
     </message>
     <message>
         <source>All</source>
-        <translation>tous</translation>
+        <translation type="obsolete">tous</translation>
     </message>
     <message>
         <source>Save as default</source>
@@ -579,14 +659,6 @@
         <source>Filter Display</source>
         <translation>Filtrage</translation>
     </message>
-    <message>
-        <source>Plain View</source>
-        <translation>Vue plane</translation>
-    </message>
-    <message>
-        <source>Folder View</source>
-        <translation>Vue avec dossiers</translation>
-    </message>
     <message>
         <source>Cancel</source>
         <translation>Annuler</translation>
@@ -604,31 +676,31 @@
     </message>
     <message>
         <source>minutes</source>
-        <translation>minutes</translation>
+        <translation type="obsolete">minutes</translation>
     </message>
     <message>
         <source>Yes</source>
-        <translation>Oui</translation>
+        <translation type="obsolete">Oui</translation>
     </message>
     <message>
         <source>No</source>
-        <translation>Non</translation>
+        <translation type="obsolete">Non</translation>
     </message>
     <message>
         <source>No Cover</source>
-        <translation>Pas d&apos;affiche</translation>
+        <translation type="obsolete">Pas d&apos;affiche</translation>
     </message>
     <message>
         <source>Unknown</source>
-        <translation>Inconnu</translation>
+        <translation type="obsolete">Inconnu</translation>
     </message>
     <message>
         <source>None</source>
-        <translation>Aucun</translation>
+        <translation type="obsolete">Aucun</translation>
     </message>
     <message>
         <source>NR</source>
-        <translation>NR</translation>
+        <translation type="obsolete">NR</translation>
     </message>
     <message>
         <source>delete failed</source>
@@ -671,22 +743,18 @@
     <name>VideoSelected</name>
     <message>
         <source>No rating available.</source>
-        <translation>Pas de note disponible.</translation>
+        <translation type="obsolete">Pas de note disponible.</translation>
     </message>
     <message>
         <source>minutes</source>
-        <translation>minutes</translation>
+        <translation type="obsolete">minutes</translation>
     </message>
 </context>
 <context>
     <name>VideoTree</name>
-    <message>
-        <source>No files found</source>
-        <translation>Pas de fichier trouvé</translation>
-    </message>
     <message>
         <source>Parental Pin:</source>
-        <translation>Code parental:</translation>
+        <translation type="obsolete">Code parental:</translation>
     </message>
     <message>
         <source>Select action</source>
