@@ -11,7 +11,7 @@
     </message>
     <message>
         <source>No Cover</source>
-        <translation>Nessuna copertina</translation>
+        <translation type="obsolete">Nessuna copertina</translation>
     </message>
     <message>
         <source>Done</source>
@@ -67,14 +67,6 @@
         <source>1 - Lowest</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>2</source>
-        <translation type="unfinished">2</translation>
-    </message>
-    <message>
-        <source>3</source>
-        <translation type="unfinished">3</translation>
-    </message>
     <message>
         <source>This is the &apos;level&apos; that MythVideo starts at. Any videos with a level at or below this will be shown in the list or while browsing by default. The Parental PIN should be set to limit changing of the default level.</source>
         <translation type="unfinished"></translation>
@@ -103,21 +95,17 @@
         <source>If set, this will cause the Video List screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>General Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Player Settings</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Parental Pin:</source>
-        <translation type="unfinished">Pin parentale:</translation>
+        <translation type="obsolete">Pin parentale:</translation>
     </message>
     <message>
         <source>No Cover</source>
-        <translation type="unfinished">Nessuna copertina</translation>
+        <translation type="obsolete">Nessuna copertina</translation>
     </message>
     <message>
         <source>Unknown</source>
@@ -127,10 +115,6 @@
         <source>None</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Unknown Rating</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Default Player</source>
         <translation type="unfinished"></translation>
@@ -245,7 +229,99 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>videos</source>
+        <source>Video Browser browses files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, this will cause the Video Browser screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video Gallery browses files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, this will cause the Video Gallery screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General Settings (1/2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General Settings (2/2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video List Loads Video Meta Data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set along with Browse Files, this will cause the Video List to load any known video metadata from the database. Turning this off can greatly  speed up how long it takes to load the Video List tree</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sorting ignores case</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, case is ignored when sorting entries in a view.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show folders for database views</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, sub folders of your video directory will be shown in supported views.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image cache size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This setting determines the number of images MythVideo will cache for views.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>^(The |A |An )</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished">Tutti</translation>
+    </message>
+    <message>
+        <source>Yes</source>
+        <translation type="unfinished">Sì</translation>
+    </message>
+    <message>
+        <source>No</source>
+        <translation type="unfinished">No</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation type="unfinished">Anno</translation>
+    </message>
+    <message>
+        <source>User Rating</source>
+        <translation type="unfinished">Giudizio</translation>
+    </message>
+    <message>
+        <source>Runtime</source>
+        <translation type="unfinished">Durata</translation>
+    </message>
+    <message>
+        <source>Filename</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video ID</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -480,11 +556,11 @@
     </message>
     <message>
         <source>No rating available.</source>
-        <translation>Nessun rating disponibile.</translation>
+        <translation type="obsolete">Nessun rating disponibile.</translation>
     </message>
     <message>
         <source>minutes</source>
-        <translation>minuti</translation>
+        <translation type="obsolete">minuti</translation>
     </message>
     <message>
         <source>Watch This Video</source>
@@ -527,7 +603,7 @@
     </message>
     <message>
         <source>Parental Pin:</source>
-        <translation>Pin parentale:</translation>
+        <translation type="obsolete">Pin parentale:</translation>
     </message>
 </context>
 <context>
@@ -542,7 +618,7 @@
     </message>
     <message>
         <source>Unknown</source>
-        <translation>Sconosciuto</translation>
+        <translation type="obsolete">Sconosciuto</translation>
     </message>
     <message>
         <source>minutes</source>
@@ -550,7 +626,7 @@
     </message>
     <message>
         <source>All</source>
-        <translation>Tutti</translation>
+        <translation type="obsolete">Tutti</translation>
     </message>
     <message>
         <source>Save as default</source>
@@ -579,14 +655,6 @@
         <source>View Details</source>
         <translation>Vedi dettagli</translation>
     </message>
-    <message>
-        <source>Plain View</source>
-        <translation>Visualizzazione semplice</translation>
-    </message>
-    <message>
-        <source>Folder View</source>
-        <translation>Visualizzazione cartelle</translation>
-    </message>
     <message>
         <source>Cancel</source>
         <translation>Annulla</translation>
@@ -596,31 +664,31 @@
     <name>VideoManager</name>
     <message>
         <source>minutes</source>
-        <translation>minuti</translation>
+        <translation type="obsolete">minuti</translation>
     </message>
     <message>
         <source>Yes</source>
-        <translation>Sì</translation>
+        <translation type="obsolete">Sì</translation>
     </message>
     <message>
         <source>No</source>
-        <translation>No</translation>
+        <translation type="obsolete">No</translation>
     </message>
     <message>
         <source>No Cover</source>
-        <translation>Nessuna copertina</translation>
+        <translation type="obsolete">Nessuna copertina</translation>
     </message>
     <message>
         <source>Unknown</source>
-        <translation>Sconosciuto</translation>
+        <translation type="obsolete">Sconosciuto</translation>
     </message>
     <message>
         <source>None</source>
-        <translation>Nessuno</translation>
+        <translation type="obsolete">Nessuno</translation>
     </message>
     <message>
         <source>NR</source>
-        <translation>NR</translation>
+        <translation type="obsolete">NR</translation>
     </message>
     <message>
         <source>delete failed</source>
@@ -671,22 +739,18 @@
     <name>VideoSelected</name>
     <message>
         <source>No rating available.</source>
-        <translation>Nessun rating disponibile.</translation>
+        <translation type="obsolete">Nessun rating disponibile.</translation>
     </message>
     <message>
         <source>minutes</source>
-        <translation>minuti</translation>
+        <translation type="obsolete">minuti</translation>
     </message>
 </context>
 <context>
     <name>VideoTree</name>
     <message>
         <source>Parental Pin:</source>
-        <translation>Pin parentale:</translation>
-    </message>
-    <message>
-        <source>No files found</source>
-        <translation>Nessun file trovato</translation>
+        <translation type="obsolete">Pin parentale:</translation>
     </message>
     <message>
         <source>Select action</source>
