@@ -11,7 +11,7 @@
     </message>
     <message>
         <source>No Cover</source>
-        <translation>カバー無し</translation>
+        <translation type="obsolete">カバー無し</translation>
     </message>
     <message>
         <source>Done</source>
@@ -67,14 +67,6 @@
         <source>1 - Lowest</source>
         <translation>1 - 低</translation>
     </message>
-    <message>
-        <source>2</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>3</source>
-        <translation></translation>
-    </message>
     <message>
         <source>This is the &apos;level&apos; that MythVideo starts at. Any videos with a level at or below this will be shown in the list or while browsing by default. The Parental PIN should be set to limit changing of the default level.</source>
         <translation type="unfinished"></translation>
@@ -103,21 +95,17 @@
         <source>If set, this will cause the Video List screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
         <translation>これをセットすると、MythVideoの開始ディレクトリで関連の有るファイルをスキャンされてなくても表示します。</translation>
     </message>
-    <message>
-        <source>General Settings</source>
-        <translation>全般設定</translation>
-    </message>
     <message>
         <source>Player Settings</source>
         <translation>プレイヤー設定</translation>
     </message>
     <message>
         <source>Parental Pin:</source>
-        <translation>再生制限ピン:</translation>
+        <translation type="obsolete">再生制限ピン:</translation>
     </message>
     <message>
         <source>No Cover</source>
-        <translation>カバー無し</translation>
+        <translation type="obsolete">カバー無し</translation>
     </message>
     <message>
         <source>Unknown</source>
@@ -129,7 +117,7 @@
     </message>
     <message>
         <source>Unknown Rating</source>
-        <translation>不明なレイティング</translation>
+        <translation type="obsolete">不明なレイティング</translation>
     </message>
     <message>
         <source>Default Player</source>
@@ -246,7 +234,99 @@
         <translation>MythVideoのデフォルトビュー。他のビューはMENUキーを押して出るポップアップから選択できます。</translation>
     </message>
     <message>
-        <source>videos</source>
+        <source>Video Browser browses files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, this will cause the Video Browser screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video Gallery browses files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, this will cause the Video Gallery screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General Settings (1/2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General Settings (2/2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video List Loads Video Meta Data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set along with Browse Files, this will cause the Video List to load any known video metadata from the database. Turning this off can greatly  speed up how long it takes to load the Video List tree</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sorting ignores case</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, case is ignored when sorting entries in a view.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show folders for database views</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, sub folders of your video directory will be shown in supported views.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image cache size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This setting determines the number of images MythVideo will cache for views.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>^(The |A |An )</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished">全て</translation>
+    </message>
+    <message>
+        <source>Yes</source>
+        <translation type="unfinished">はい</translation>
+    </message>
+    <message>
+        <source>No</source>
+        <translation type="unfinished">いいえ</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation type="unfinished">年</translation>
+    </message>
+    <message>
+        <source>User Rating</source>
+        <translation type="unfinished">ユーザー格付け</translation>
+    </message>
+    <message>
+        <source>Runtime</source>
+        <translation type="unfinished">所用時間</translation>
+    </message>
+    <message>
+        <source>Filename</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video ID</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -481,11 +561,11 @@
     </message>
     <message>
         <source>No rating available.</source>
-        <translation>レイティングは使用できません.</translation>
+        <translation type="obsolete">レイティングは使用できません.</translation>
     </message>
     <message>
         <source>minutes</source>
-        <translation>分</translation>
+        <translation type="obsolete">分</translation>
     </message>
     <message>
         <source>Watch This Video</source>
@@ -528,7 +608,7 @@
     </message>
     <message>
         <source>Parental Pin:</source>
-        <translation>再生制限ピン:</translation>
+        <translation type="obsolete">再生制限ピン:</translation>
     </message>
 </context>
 <context>
@@ -543,7 +623,7 @@
     </message>
     <message>
         <source>Unknown</source>
-        <translation>不明</translation>
+        <translation type="obsolete">不明</translation>
     </message>
     <message>
         <source>minutes</source>
@@ -551,7 +631,7 @@
     </message>
     <message>
         <source>All</source>
-        <translation>全て</translation>
+        <translation type="obsolete">全て</translation>
     </message>
     <message>
         <source>Save as default</source>
@@ -580,14 +660,6 @@
         <source>View Details</source>
         <translation>詳細を表示する</translation>
     </message>
-    <message>
-        <source>Plain View</source>
-        <translation>プレインビュー</translation>
-    </message>
-    <message>
-        <source>Folder View</source>
-        <translation>フォルダービュー</translation>
-    </message>
     <message>
         <source>Cancel</source>
         <translation>キャンセル</translation>
@@ -605,31 +677,27 @@
     </message>
     <message>
         <source>minutes</source>
-        <translation>分</translation>
+        <translation type="obsolete">分</translation>
     </message>
     <message>
         <source>Yes</source>
-        <translation>はい</translation>
+        <translation type="obsolete">はい</translation>
     </message>
     <message>
         <source>No</source>
-        <translation>いいえ</translation>
+        <translation type="obsolete">いいえ</translation>
     </message>
     <message>
         <source>No Cover</source>
-        <translation>カバー無し</translation>
+        <translation type="obsolete">カバー無し</translation>
     </message>
     <message>
         <source>Unknown</source>
-        <translation>不明</translation>
+        <translation type="obsolete">不明</translation>
     </message>
     <message>
         <source>None</source>
-        <translation>無し</translation>
-    </message>
-    <message>
-        <source>NR</source>
-        <translation></translation>
+        <translation type="obsolete">無し</translation>
     </message>
     <message>
         <source>delete failed</source>
@@ -672,22 +740,18 @@
     <name>VideoSelected</name>
     <message>
         <source>No rating available.</source>
-        <translation>レイティングは使用できません.</translation>
+        <translation type="obsolete">レイティングは使用できません.</translation>
     </message>
     <message>
         <source>minutes</source>
-        <translation>分</translation>
+        <translation type="obsolete">分</translation>
     </message>
 </context>
 <context>
     <name>VideoTree</name>
     <message>
         <source>Parental Pin:</source>
-        <translation>再生制限ピン:</translation>
-    </message>
-    <message>
-        <source>No files found</source>
-        <translation>ファイルを見つけられませんでした</translation>
+        <translation type="obsolete">再生制限ピン:</translation>
     </message>
     <message>
         <source>Select action</source>
