@@ -11,7 +11,7 @@
     </message>
     <message>
         <source>No Cover</source>
-        <translation>Geen Cover</translation>
+        <translation type="obsolete">Geen Cover</translation>
     </message>
     <message>
         <source>Done</source>
@@ -22,15 +22,15 @@
     <name>FileAssocDialog</name>
     <message>
         <source>Please enter the new extension:</source>
-        <translation>Geef nieuwe extensie:</translation>
+        <translation>Nieuwe extensie:</translation>
     </message>
     <message>
         <source>Create new extension</source>
-        <translation>Maak nieuwe extensie</translation>
+        <translation>Nieuwe extensie maken</translation>
     </message>
     <message>
         <source>Cancel</source>
-        <translation>Annuleer</translation>
+        <translation>Annuleren</translation>
     </message>
     <message>
         <source>Done</source>
@@ -42,7 +42,7 @@
     </message>
     <message>
         <source>Delete</source>
-        <translation>Wis</translation>
+        <translation>Verwijderen</translation>
     </message>
 </context>
 <context>
@@ -67,14 +67,6 @@
         <source>1 - Lowest</source>
         <translation>1 - Laagste</translation>
     </message>
-    <message>
-        <source>2</source>
-        <translation>2</translation>
-    </message>
-    <message>
-        <source>3</source>
-        <translation>3</translation>
-    </message>
     <message>
         <source>This is the &apos;level&apos; that MythVideo starts at. Any videos with a level at or below this will be shown in the list or while browsing by default. The Parental PIN should be set to limit changing of the default level.</source>
         <translation>Dit is het niveau waarin MythVideo start. Alle films met een gelijk of lager niveau worden standaard getoond. De &apos;Parental Control&apos; PIN kan best zo ingesteld worden dat het niveau zo weinig mogelijk veranderd moet worden.</translation>
@@ -89,7 +81,7 @@
     </message>
     <message>
         <source>Show Unknown File Types</source>
-        <translation>Toon onbekende bestandstypes</translation>
+        <translation>Onbekende bestandstypes tonen</translation>
     </message>
     <message>
         <source>If set, all files below the Myth Video directory will be displayed unless their extension is explicitly set to be ignored. </source>
@@ -97,27 +89,23 @@
     </message>
     <message>
         <source>Video List browses files</source>
-        <translation>Film Lijst bladert bestanden</translation>
+        <translation>Filmlijst bladert bestanden</translation>
     </message>
     <message>
         <source>If set, this will cause the Video List screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
         <translation>Indien geselecteerd worden alle relevante bestanden in de MythVideo-map getoond. Gescand of niet.</translation>
     </message>
-    <message>
-        <source>General Settings</source>
-        <translation>Algemene Instellingen</translation>
-    </message>
     <message>
         <source>Player Settings</source>
-        <translation>Instellingen voor het Afspeelprogramma</translation>
+        <translation>Instellingen voor het afspeelprogramma</translation>
     </message>
     <message>
         <source>Parental Pin:</source>
-        <translation>&apos;Parental PIN&apos;:</translation>
+        <translation type="obsolete">&apos;Parental PIN&apos;:</translation>
     </message>
     <message>
         <source>No Cover</source>
-        <translation>Geen Cover</translation>
+        <translation type="obsolete">Geen cover</translation>
     </message>
     <message>
         <source>Unknown</source>
@@ -129,7 +117,7 @@
     </message>
     <message>
         <source>Unknown Rating</source>
-        <translation>Onbekende Beoordeling</translation>
+        <translation type="obsolete">Onbekende beoordeling</translation>
     </message>
     <message>
         <source>Default Player</source>
@@ -244,10 +232,102 @@
     </message>
     <message>
         <source>The default view for MythVideo. Other views can be reached via the popup menu available via the MENU key.</source>
+        <translation>Het standaard uiterlijk van MythVideo. Andere zijn mogelijk via het popup-menu (MENU),</translation>
+    </message>
+    <message>
+        <source>Video Browser browses files</source>
+        <translation>Video Browser bladert bestanden</translation>
+    </message>
+    <message>
+        <source>If set, this will cause the Video Browser screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
+        <translation>Als dit is ingeschakeld, zal het Video Blader scherm alle relevante bestanden in de MythVideo map laten zien, zelfs als ze niet gescanned zijn.</translation>
+    </message>
+    <message>
+        <source>Video Gallery browses files</source>
+        <translation>Video Gallerij bladert in bestanden</translation>
+    </message>
+    <message>
+        <source>If set, this will cause the Video Gallery screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
+        <translation>Als dit is ingeschakeld, zal het Video Gallerij scherm alle relevante bestanden in de MythVideo map laten zien, zelfs als ze niet gescanned zijn.</translation>
+    </message>
+    <message>
+        <source>General Settings (1/2)</source>
+        <translation>Globale Instellingen (1/2)</translation>
+    </message>
+    <message>
+        <source>General Settings (2/2)</source>
+        <translation>Globale Instellingen (2/2)</translation>
+    </message>
+    <message>
+        <source>Video List Loads Video Meta Data</source>
+        <translation>Video Lijst Laadt Video Meta Data</translation>
+    </message>
+    <message>
+        <source>If set along with Browse Files, this will cause the Video List to load any known video metadata from the database. Turning this off can greatly  speed up how long it takes to load the Video List tree</source>
+        <translation>Als dit is ingeschakeld samen met Blader Bestanden, zal de Video Lijst bekende metadata uit de database halen. Dit uitschakelen kan het maken van de Video Lijst enorm versnellen.</translation>
+    </message>
+    <message>
+        <source>Sorting ignores case</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>videos</source>
+        <source>If set, case is ignored when sorting entries in a view.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show folders for database views</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, sub folders of your video directory will be shown in supported views.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image cache size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This setting determines the number of images MythVideo will cache for views.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>^(The |A |An )</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished">Alle</translation>
+    </message>
+    <message>
+        <source>Yes</source>
+        <translation type="unfinished">Ja</translation>
+    </message>
+    <message>
+        <source>No</source>
+        <translation type="unfinished">Neen</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation type="unfinished">Jaar</translation>
+    </message>
+    <message>
+        <source>User Rating</source>
+        <translation type="unfinished">Gebruikersbeoordeling</translation>
+    </message>
+    <message>
+        <source>Runtime</source>
+        <translation type="unfinished">Speeltijd</translation>
+    </message>
+    <message>
+        <source>Filename</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video ID</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -482,11 +562,11 @@
     </message>
     <message>
         <source>No rating available.</source>
-        <translation>Geen beoordeling beschikbaar.</translation>
+        <translation type="obsolete">Geen beoordeling beschikbaar.</translation>
     </message>
     <message>
         <source>minutes</source>
-        <translation>minuten</translation>
+        <translation type="obsolete">minuten</translation>
     </message>
     <message>
         <source>Watch This Video</source>
@@ -529,7 +609,7 @@
     </message>
     <message>
         <source>Parental Pin:</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Ouderlijk toezicht Pincode:</translation>
     </message>
 </context>
 <context>
@@ -544,7 +624,7 @@
     </message>
     <message>
         <source>Unknown</source>
-        <translation>Onbekend</translation>
+        <translation type="obsolete">Onbekend</translation>
     </message>
     <message>
         <source>minutes</source>
@@ -552,7 +632,7 @@
     </message>
     <message>
         <source>All</source>
-        <translation>Alle</translation>
+        <translation type="obsolete">Alle</translation>
     </message>
     <message>
         <source>Save as default</source>
@@ -581,14 +661,6 @@
         <source>View Details</source>
         <translation>Bekijk Details</translation>
     </message>
-    <message>
-        <source>Plain View</source>
-        <translation>Overzicht alle folders</translation>
-    </message>
-    <message>
-        <source>Folder View</source>
-        <translation>Gebruik Folders</translation>
-    </message>
     <message>
         <source>Cancel</source>
         <translation>Annuleer</translation>
@@ -598,31 +670,31 @@
     <name>VideoManager</name>
     <message>
         <source>minutes</source>
-        <translation>minuten</translation>
+        <translation type="obsolete">minuten</translation>
     </message>
     <message>
         <source>Yes</source>
-        <translation>Ja</translation>
+        <translation type="obsolete">Ja</translation>
     </message>
     <message>
         <source>No</source>
-        <translation>Neen</translation>
+        <translation type="obsolete">Neen</translation>
     </message>
     <message>
         <source>No Cover</source>
-        <translation>Geen Cover</translation>
+        <translation type="obsolete">Geen Cover</translation>
     </message>
     <message>
         <source>Unknown</source>
-        <translation>Onbekend</translation>
+        <translation type="obsolete">Onbekend</translation>
     </message>
     <message>
         <source>None</source>
-        <translation>Geen</translation>
+        <translation type="obsolete">Geen</translation>
     </message>
     <message>
         <source>NR</source>
-        <translation>Niet Beoordeeld</translation>
+        <translation type="obsolete">Niet Beoordeeld</translation>
     </message>
     <message>
         <source>delete failed</source>
@@ -673,22 +745,18 @@
     <name>VideoSelected</name>
     <message>
         <source>No rating available.</source>
-        <translation>Geen beoordeling beschikbaar.</translation>
+        <translation type="obsolete">Geen beoordeling beschikbaar.</translation>
     </message>
     <message>
         <source>minutes</source>
-        <translation>minuten</translation>
+        <translation type="obsolete">minuten</translation>
     </message>
 </context>
 <context>
     <name>VideoTree</name>
     <message>
         <source>Parental Pin:</source>
-        <translation>&apos;Parental Control&apos; PIN:</translation>
-    </message>
-    <message>
-        <source>No files found</source>
-        <translation>Geen bestanden gevonden</translation>
+        <translation type="obsolete">&apos;Parental Control&apos; PIN:</translation>
     </message>
     <message>
         <source>Select action</source>
