@@ -11,7 +11,7 @@
     </message>
     <message>
         <source>No Cover</source>
-        <translation>Sem Capa</translation>
+        <translation type="obsolete">Sem Capa</translation>
     </message>
     <message>
         <source>Done</source>
@@ -67,14 +67,6 @@
         <source>1 - Lowest</source>
         <translation>1 - Permissivo</translation>
     </message>
-    <message>
-        <source>2</source>
-        <translation>2</translation>
-    </message>
-    <message>
-        <source>3</source>
-        <translation>3</translation>
-    </message>
     <message>
         <source>This is the &apos;level&apos; that MythVideo starts at. Any videos with a level at or below this will be shown in the list or while browsing by default. The Parental PIN should be set to limit changing of the default level.</source>
         <translation>Este é o nível de acesso que o MythVideo usa quando é iniciado. Todos os filmes com um nível igual ou inferior serão mostrados na lista ou serão navegáveis por omissão. O código de acesso deverá ser preenchido para permitir a mudança do nível por omissão.</translation>
@@ -107,21 +99,17 @@
         <source>Default Player</source>
         <translation>Comando Padrão</translation>
     </message>
-    <message>
-        <source>General Settings</source>
-        <translation>Configurações Globais</translation>
-    </message>
     <message>
         <source>Player Settings</source>
         <translation>Configurações de Leitura</translation>
     </message>
     <message>
         <source>Parental Pin:</source>
-        <translation>Código de Acesso:</translation>
+        <translation type="obsolete">Código de Acesso:</translation>
     </message>
     <message>
         <source>No Cover</source>
-        <translation>Sem Capa</translation>
+        <translation type="obsolete">Sem Capa</translation>
     </message>
     <message>
         <source>Unknown</source>
@@ -133,7 +121,7 @@
     </message>
     <message>
         <source>Unknown Rating</source>
-        <translation>Classificação Desconhecida</translation>
+        <translation type="obsolete">Classificação Desconhecida</translation>
     </message>
     <message>
         <source>Newly scanned files are browsable by default</source>
@@ -245,7 +233,99 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>videos</source>
+        <source>Video Browser browses files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, this will cause the Video Browser screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video Gallery browses files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, this will cause the Video Gallery screen to show all relevant files below the MythVideo starting directory whether they have been scanned or not.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General Settings (1/2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General Settings (2/2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video List Loads Video Meta Data</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set along with Browse Files, this will cause the Video List to load any known video metadata from the database. Turning this off can greatly  speed up how long it takes to load the Video List tree</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Sorting ignores case</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, case is ignored when sorting entries in a view.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show folders for database views</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, sub folders of your video directory will be shown in supported views.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Image cache size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>This setting determines the number of images MythVideo will cache for views.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>^(The |A |An )</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Yes</source>
+        <translation type="unfinished">Sim</translation>
+    </message>
+    <message>
+        <source>No</source>
+        <translation type="unfinished">Não</translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Year</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>User Rating</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Runtime</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Filename</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video ID</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -480,11 +560,11 @@
     </message>
     <message>
         <source>No rating available.</source>
-        <translation>Não existe classificação disponível.</translation>
+        <translation type="obsolete">Não existe classificação disponível.</translation>
     </message>
     <message>
         <source>minutes</source>
-        <translation type="unfinished">minutos</translation>
+        <translation type="obsolete">minutos</translation>
     </message>
     <message>
         <source>Watch This Video</source>
@@ -527,7 +607,7 @@
     </message>
     <message>
         <source>Parental Pin:</source>
-        <translation type="unfinished">Código de Acesso:</translation>
+        <translation type="obsolete">Código de Acesso:</translation>
     </message>
 </context>
 <context>
@@ -542,16 +622,12 @@
     </message>
     <message>
         <source>Unknown</source>
-        <translation type="unfinished">Desconhecido</translation>
+        <translation type="obsolete">Desconhecido</translation>
     </message>
     <message>
         <source>minutes</source>
         <translation type="unfinished">minutos</translation>
     </message>
-    <message>
-        <source>All</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Save as default</source>
         <translation type="unfinished"></translation>
@@ -579,14 +655,6 @@
         <source>View Details</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Plain View</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Folder View</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Cancel</source>
         <translation type="unfinished">Cancelar</translation>
@@ -604,31 +672,31 @@
     </message>
     <message>
         <source>minutes</source>
-        <translation>minutos</translation>
+        <translation type="obsolete">minutos</translation>
     </message>
     <message>
         <source>Yes</source>
-        <translation>Sim</translation>
+        <translation type="obsolete">Sim</translation>
     </message>
     <message>
         <source>No</source>
-        <translation>Não</translation>
+        <translation type="obsolete">Não</translation>
     </message>
     <message>
         <source>No Cover</source>
-        <translation>Sem Capa</translation>
+        <translation type="obsolete">Sem Capa</translation>
     </message>
     <message>
         <source>Unknown</source>
-        <translation>Desconhecido</translation>
+        <translation type="obsolete">Desconhecido</translation>
     </message>
     <message>
         <source>None</source>
-        <translation>Nenhum</translation>
+        <translation type="obsolete">Nenhum</translation>
     </message>
     <message>
         <source>NR</source>
-        <translation>SC</translation>
+        <translation type="obsolete">SC</translation>
     </message>
     <message>
         <source>delete failed</source>
@@ -671,22 +739,18 @@
     <name>VideoSelected</name>
     <message>
         <source>No rating available.</source>
-        <translation type="unfinished">Não existe classificação disponível.</translation>
+        <translation type="obsolete">Não existe classificação disponível.</translation>
     </message>
     <message>
         <source>minutes</source>
-        <translation type="unfinished">minutos</translation>
+        <translation type="obsolete">minutos</translation>
     </message>
 </context>
 <context>
     <name>VideoTree</name>
     <message>
         <source>Parental Pin:</source>
-        <translation>Código de Acesso:</translation>
-    </message>
-    <message>
-        <source>No files found</source>
-        <translation>Não foi encontrado nenhum ficheiro</translation>
+        <translation type="obsolete">Código de Acesso:</translation>
     </message>
     <message>
         <source>Select action</source>
