@@ -12,23 +12,37 @@
 # v1.1
 # - Added amazon.com covers and improved handling for imdb posters
 # v1.2
-#     - when searching amazon, try searching for main movie name and if nothing is found, search for informal name
-#     - better handling for amazon posters, see if movie title is a substring in the search results returned by amazon
+#     - when searching amazon, try searching for main movie name and if nothing
+#       is found, search for informal name
+#     - better handling for amazon posters, see if movie title is a substring
+#       in the search results returned by amazon
 #     - fixed redirects for some movies on impawards
+# v1.3
+#     - fixed search for low res images (imdb changed the page layout)
+#     - added cinemablend poster search
+#     - added nexbase poster search
+#     - removed amazon.com searching for now
+
+# changes:
+# 9-10-2006: Anduin Withers
+#   Changed output to utf8
 
 use LWP::Simple;      # libwww-perl providing simple HTML get actions
 use HTML::Entities;
 use URI::Escape;
-use XML::Simple;
 
 
 use vars qw($opt_h $opt_r $opt_d $opt_i $opt_v $opt_D $opt_M $opt_P);
 use Getopt::Std; 
 
 $title = "IMDB Query"; 
-$version = "v1.2";
+$version = "v1.3.2";
 $author = "Tim Harvey, Andrei Rjeousski";
 
+my @countries = qw(USA UK Canada Japan);
+
+binmode(STDOUT, ":utf8");
+
 # display usage
 sub usage {
    print "usage: $0 -hdrviMPD [parameters]\n";
@@ -68,6 +82,13 @@ sub help {
    usage();
 }
 
+sub trim {
+   my ($str) = @_;
+   $str =~ s/^\s+//;
+   $str =~ s/\s+$//;
+   return $str;
+}
+
 # returns text within 'data' between 'beg' and 'end' matching strings
 sub parseBetween {
    my ($data, $beg, $end)=@_; # grab parameters
@@ -90,6 +111,8 @@ sub getMovieData {
    my ($movieid)=@_; # grab movieid parameter
    if (defined $opt_d) { printf("# looking for movie id: '%s'\n", $movieid);}
 
+   my $name_link_pat = qr'<a href="/name/[^"]*">([^<]*)</a>'m;
+
    # get the search results  page
    my $request = "http://www.imdb.com/title/tt" . $movieid . "/";
    if (defined $opt_d) { printf("# request: '%s'\n", $request); }
@@ -97,121 +120,103 @@ sub getMovieData {
    if (defined $opt_r) { printf("%s", $response); }
 
    # parse title and year
+   my $year = "";
    my $title = parseBetween($response, "<title>", "</title>");
-   $title =~ m#(.+) \((\d+).*\)#;  # Note some years have a /II after them?
-   $title = $1;
-   my $year = $2;
+   if ($title =~ m#(.+) \((\d+).*\)#) # Note some years have a /II after them?
+   {
+      $title = $1;
+      $year = $2;
+   }
+   elsif ($title =~ m#(.+) \(\?\?\?\?\)#)
+   {
+      $title = $1;
+   }
 
    # parse director 
-   my $director = parseBetween($response, ">Directed by</b>", "/a><br>");
-   $director = parseBetween($director, "/\">", "<");
+   my $data = parseBetween($response, ">Director:</h5>", "</div>");
+   if (!length($data)) {
+      $data = parseBetween($response, ">Directors:</h5>", "</div>");
+   }
+   my $director = join(",", ($data =~ m/$name_link_pat/g));
 
    # parse writer 
    # (Note: this takes the 'first' writer, may want to include others)
-   my $writer = parseBetween($response, ">Writing credits</b>", "</table>");
-   $writer = parseBetween($writer, "/\">", "</");
+   $data = parseBetween($response, ">Writers <a href=\"/wga\">(WGA)</a>:</h5>", "</div>");
+   if (!length($data)) {
+         $data = parseBetween($response, ">Writer:</h5>", "</div>");
+   }
+   if (!length($data)) {
+         $data = parseBetween($response, ">Writers:</h5>", "</div>");
+   }
+   my $writer = join(",", ($data =~ m/$name_link_pat/g));
 
    # parse plot
-   my $plot = parseBetween($response, ">Plot Outline:</b> ", "<a href=\"");
+   my $plot = parseBetween($response, ">Plot Outline:</h5> ", "</div>");
    if (!$plot) {
-      $plot = parseBetween($response, ">Plot Summary:</b> ", "<a href=\"");
+      $plot = parseBetween($response, ">Plot Summary:</h5> ", "</div>");
+   }
+
+   if ($plot) {
+      # replace name links in plot (example 0388795)
+      $plot =~ s/$name_link_pat/$1/g;
+
+      # replace title links
+      my $title_link_pat = qr!<a href="/title/[^"]*">([^<]*)</a>!m;
+      $plot =~ s/$title_link_pat/$1/g;
+
+      # plot ends at first remaining link
+      my $plot_end = index($plot, "<a ");
+      if ($plot_end != -1) {
+         $plot = substr($plot, 0, $plot_end);
+      }
+      $plot = trim($plot);
    }
 
    # parse user rating
-   my $userrating = parseBetween($response, ">User Rating:</b>", "> (");
+   my $userrating = parseBetween($response, ">User Rating:</b>", "</b>");
    $userrating = parseBetween($userrating, "<b>", "/");
 
    # parse MPAA rating
    my $ratingcountry = "USA";
-   my $movierating = parseBetween($response, ">MPAA</a>:</b> ", "<br>");
+   my $movierating = trim(parseBetween($response, ">MPAA</a>:</h5>", "</div>"));
    if (!$movierating) {
-       $movierating = parseBetween($response, ">Certification:</b>", "<br>");
+       $movierating = parseBetween($response, ">Certification:</h5>", "</div>");
        $movierating = parseBetween($movierating, "certificates=$ratingcountry",
                                    "/a>");
        $movierating = parseBetween($movierating, ">", "<");
    }
 
    # parse movie length
-   my $runtime = parseBetween($response, ">Runtime:</b>\n", " min");
+   my $rawruntime = trim(parseBetween($response, ">Runtime:</h5>", "</div>"));
+   my $runtime = trim(parseBetween($rawruntime, "", " min"));
+   for my $country (@countries) {
+      last if ($runtime =~ /^-?\d/);
+      $runtime = trim(parseBetween($rawruntime, "$country:", " min"));
+   }
 
    # parse cast 
    #  Note: full cast would be from url: 
    #    www.imdb.com/title/<movieid>/fullcredits
-   my @actors;
    my $cast = "";
-   my $count = 0;
-   my $data = parseBetween($response, "Cast overview, first billed only:",
+   $data = parseBetween($response, "Cast overview, first billed only",
                                "/table>"); 
    if ($data) {
-      my $beg = "/\">"; 
-      my $end = "</a>";
-      my $start = index($data, $beg);
-      my $finish = index($data, $end, $start);
-      my $actor;
-      while ($start != -1) {
-         $start += length($beg);
-         $actor = substr($data, $start, $finish - $start);
-         # add to array
-         $actors[$count++] = $actor;
-
-         # advance data to next movie
-         $data = substr($data, - (length($data) - $finish));
-         $start = index($data, $beg);
-         $finish = index($data, $end, $start + 1); 
-      }
-      $cast = join(',', @actors);
+      $cast = join(',', ($data =~ m/$name_link_pat/g));
    }
    
    
    # parse genres 
-   my @genres;
    my $lgenres = "";
-   $count = 0;
-   $data = parseBetween($response, "<b class=\"ch\">Genre:</b>","<a href=\"/rg/title-tease/keywords/title/tt$movieid/keywords\">(more)</a>"); 
+   $data = parseBetween($response, "<h5>Genre:</h5>","</div>"); 
    if ($data) {
-      my $beg = "/\">"; 
-      my $end = "</a>";
-      my $start = index($data, $beg);
-      my $finish = index($data, $end, $start);
-      my $genre;
-      while ($start != -1) {
-         $start += length($beg);
-         $genre = substr($data, $start, $finish - $start);
-         # add to array
-         $genres[$count++] = $genre;
-
-         # advance data to next movie
-         $data = substr($data, - (length($data) - $finish));
-         $start = index($data, $beg);
-         $finish = index($data, $end, $start + 1); 
-      }
-      $lgenres = join(',', @genres);
+      my $genre_pat = qr'/Sections/Genres/(?:[a-z ]+/)*">([^<]+)<'im;
+      $lgenres = join(',', ($data =~ /$genre_pat/g));
    }
    
    # parse countries 
-   my @countries;
-   my $lcountries = "";
-   $count = 0;
-   $data = parseBetween($response, "<b class=\"ch\">Country:</b>","<br>"); 
-   if ($data) {
-      my $beg = "/\">"; 
-      my $end = "</a>";
-      my $start = index($data, $beg);
-      my $finish = index($data, $end, $start);
-      my $country;
-      while ($start != -1) {
-         $start += length($beg);
-         $country = substr($data, $start, $finish - $start);
-         # add to array
-         $countries[$count++] = $country;
-
-         # advance data to next movie
-         $data = substr($data, - (length($data) - $finish));
-         $start = index($data, $beg);
-         $finish = index($data, $end, $start + 1); 
-      }
-      $lcountries = join(',', @countries);
-   }
+   $data = parseBetween($response, "Country:</h5>","</div>"); 
+   my $country_pat = qr'/Sections/Countries/[A-Z]+/">([^<]+)</a>'i;
+   my $lcountries = join(",", ($data =~ m/$country_pat/g));
 
    # output fields (these field names must match what MythVideo is looking for)
    print "Title:$title\n";
@@ -238,6 +243,8 @@ sub getMoviePoster {
    my $response = get $request;
    if (defined $opt_r) { printf("%s", $response); }
 
+   if (!defined $response) {return;}
+
    my $uri = "";
 
    # look for references to impawards.com posters - they are high quality
@@ -255,17 +262,16 @@ sub getMoviePoster {
       if (defined $opt_d) { printf("# got %i bytes\n", length($impres)); }
       if (defined $opt_r) { printf("%s", $impres); }      
 
-	# making sure it isnt redirect
-	$uri = parseBetween($impres, "0;URL=..", "\">");
-	if ($uri ne "") {
-		if (defined $opt_d) { printf("# processing redirect to %s\n",$uri); }
-		# this was redirect
-                $impsite = $site . $uri;
-                $impres = get $impsite;
-	}
-
+      # making sure it isnt redirect
+      $uri = parseBetween($impres, "0;URL=..", "\">");
+      if ($uri ne "") {
+         if (defined $opt_d) { printf("# processing redirect to %s\n",$uri); }
+         # this was redirect
+         $impsite = $site . $uri;
+         $impres = get $impsite;
+      }
       
-      # do stuff normally	
+      # do stuff normally
       $uri = parseBetween($impres, "<img SRC=\"posters/", "\" ALT");
       # uri here is relative... patch it up to make a valid uri
       if (!($uri =~ /http:(.*)/ )) {
@@ -275,6 +281,36 @@ sub getMoviePoster {
       if (defined $opt_d) { print "# found ipmawards poster: $uri\n"; }
    }
 
+   # try looking on nexbase
+   if ($uri eq "" && $response =~ m/<a href="([^"]*)">([^"]*?)nexbase/i) {
+      if ($1 ne "") {
+         if (defined $opt_d) { print "# found nexbase poster page: $1 \n"; }
+         my $cinres = get $1;
+         if (defined $opt_d) { printf("# got %i bytes\n", length($cinres)); }
+         if (defined $opt_r) { printf("%s", $cinres); }
+
+         if ($cinres =~ m/<a id="photo_url" href="([^"]*?)" ><\/a>/i) {
+            if (defined $opt_d) { print "# nexbase url retreived\n"; }
+            $uri = $1;
+         }
+      }
+   }
+
+   # try looking on cinemablend
+   if ($uri eq "" && $response =~ m/<a href="([^"]*)">([^"]*?)cinemablend/i) {
+      if ($1 ne "") {
+         if (defined $opt_d) { print "# found cinemablend poster page: $1 \n"; }
+         my $cinres = get $1;
+         if (defined $opt_d) { printf("# got %i bytes\n", length($cinres)); }
+         if (defined $opt_r) { printf("%s", $cinres); }
+
+         if ($cinres =~ m/<td align=center><img src="([^"]*?)" border=1><\/td>/i) {
+            if (defined $opt_d) { print "# cinemablend url retreived\n"; }
+            $uri = "http://www.cinemablend.com/".$1;   
+         }
+      }
+   }
+
    # if the impawards site attempt didn't give a filename grab it from imdb
    if ($uri eq "") {
        if (defined $opt_d) { print "# looking for imdb posters\n"; }
@@ -287,9 +323,8 @@ sub getMoviePoster {
           if (defined $opt_d) { print "# no poster found\n"; }
        }
    }
-   
-   # now we couldnt even find lowres poster from IMDB, lets try looking for dvd
-   # cover on amazon.com   
+
+
 
    my @movie_titles;
    my $found_low_res = 0;
@@ -297,12 +332,21 @@ sub getMoviePoster {
    
    # no poster found, take lowres image from imdb
    if ($uri eq "") {
-       if (defined $opt_d) { print "# looking for lowres imdb posters\n"; }
-       my $host = "http://www.imdb.com/title/tt" . $movieid . "/";
-       $response = get $host;
+      if (defined $opt_d) { print "# looking for lowres imdb posters\n"; }
+      my $host = "http://www.imdb.com/title/tt" . $movieid . "/";
+      $response = get $host;
+
+      # Better handling for low resolution posters
+      # 
+      if ($response =~ m/<a name="poster".*<img.*src="([^"]*).*<\/a>/ig) {
+         if (defined $opt_d) { print "# found low res poster at: $1\n"; }
+         $uri = $1;
+         $found_low_res = 1;
+      } else {
+         if (defined $opt_d) { print "# no low res poster found\n"; }
+         $uri = "";
+      }
 
-       $uri = parseBetween($response, "alt=\"cover\" src=\"http://ia.imdb.com/media/imdb/", "\"");
-       
       if (defined $opt_d) { print "# starting to look for movie title\n"; }
       
       # get main title
@@ -312,97 +356,12 @@ sub getMoviePoster {
 
       # now we get all other possible movie titles and store them in the titles array
       while($response =~ m/>([^>^\(]*)([ ]{0,1}\([^\)]*\)[^\(^\)]*[ ]{0,1}){0,1}\(informal title\)/g) {
-         $movie_titles[$k++] = $1;
-         chomp($movie_titles[$k-1]);
-         $movie_titles[$k-1] =~ s/^\s+//;
-         $movie_titles[$k-1] =~ s/\s+$//;
+         $movie_titles[$k++] = trim($1);
          if (defined $opt_d) { print "# Title: ".$movie_titles[$k-1]."\n"; }
       }
        
-       if ($uri ne "" ) {
-           $uri = "http://ia.imdb.com/media/imdb/".$uri;
-           $found_low_res = 1;
-       } else {
-          if (defined $opt_d) { print "# no poster found\n"; }
-       }
    }
    
-   # now we couldnt even find lowres poster from IMDB, lets try looking for dvd
-   # cover on amazon.com
-   if ($uri eq "" or $found_low_res) {
-      if (defined $opt_d) { print "# starting to look for poster on Amazon.com\n"; }
-
-      my $titleid = 0;
-      my $found = 0;
-      my $ama_uri = "";
-      my $xml_parser = XML::Simple->new();
-      
-         
-      do {
-         # get rid of the year
-         $movie_titles[$titleid] =~ s/ ?\([^\)]+\) ?//g;
-         $movie_titles[$titleid] =~ /(.*), The$/i;
-         if ($1) { $movie_titles[$titleid] = $1; }
-
-         $movie_titles[$titleid] =~ s/[\"\']//g; # if we give amazon quotes they give them back
-      
-         if (defined $opt_d) { print "# Searching for: $movie_titles[$titleid]\n"; }
-
-         # Encode the movie title to be save
-         my $safe_movie_title = $movie_titles[$titleid];
-         $safe_movie_title =~ s/([^A-Za-z0-9])/sprintf("%%%02X", ord($1))/seg;      
-         # request XML info from amazon
-         my $xml_uri = "http://xml.amazon.com/onca/xml3?t=000&dev-t=000&KeywordSearch=".$safe_movie_title."&mode=dvd&type=lite&page=1&f=xml";
-         if (defined $opt_d) { print "# Amazon request string is: $xml_uri\n";}
-
-         # get the response
-         $response = get $xml_uri;
-         if (defined $opt_r) { printf("%s", $response); }
-      
-         # parse the response
-         my $xml_doc = $xml_parser->XMLin($response);
-
-         # if we only got one result, fake it as array
-         if (ref($xml_doc->{Details}) ne 'ARRAY') {
-            my @tmpArray = ($xml_doc->{Details});
-            $xml_doc->{Details} = \@tmpArray;
-         }
-
-         $k = 0;
-         do {
-            if (ref($xml_doc->{Details}->[$k]) eq 'HASH') {
-               my $tmp_movie_title = $xml_doc->{Details}->[$k]->{ProductName};
-               $tmp_movie_title =~ s/[\"\']//g;
-               if (defined $opt_d) { print "# Amazon: comparing (" . $tmp_movie_title . ") to (" . $movie_titles[$titleid] . ")\n"; }
-               if ($tmp_movie_title =~ /.*$movie_titles[$titleid].*/) {
-                  if (defined $opt_d) { print "# Amazon: found poster " . $xml_doc->{Details}->[$k]->{ImageUrlLarge} . "\n"; }
-                  $ama_uri = $xml_doc->{Details}->[$k]->{ImageUrlLarge};
-                  $found = 1;
-               }
-            }
-
-           $k++;
-        } until ($found || $k == 5);
-        #only search through first 5 matches
-
-         $titleid++;
-      } until ($found || $titleid > $#movie_titles);
-      
-      my $image = get $ama_uri if (defined($ama_uri) && $ama_uri ne "");
-      if ($ama_uri ne "" && length($image) eq "807") {
-         if (defined $opt_d) { printf("# this image is blank\n"); }
-         $ama_uri = "";
-      }
-      
-      if (!defined($ama_uri)) {
-         $ama_uri = "";
-      }
-	
-      if ($ama_uri ne "") {
-	$uri = $ama_uri;
-      }
-   }
-
    print "$uri\n";
 }
 
@@ -460,7 +419,7 @@ sub getMovieList {
    # check to see if we got a results page or a movie page
    #    looking for 'add=<movieid>" target=' which only exists
    #    in a movie description page 
-   my $movienum = parseBetween($response, "add=", "\" target=");
+   my $movienum = parseBetween($response, "add=", "\">");
    if ($movienum) {
        if (defined $opt_d) { printf("# redirected to movie page\n"); }
        my $movietitle = parseBetween($response, "<title>", "</title>"); 
@@ -474,16 +433,16 @@ sub getMovieList {
    #    possible matches are grouped in several catagories:  
    #        exact, partial, and approximate
    my $popular_results = parseBetween($response, "<b>Popular Titles</b>",
-                                              "</ol>");
+                                              "</table>");
    my $exact_matches = parseBetween($response, "<b>Titles (Exact Matches)</b>",
-                                              "</ol>");
+                                              "</table>");
    my $partial_matches = parseBetween($response, "<b>Titles (Partial Matches)</b>", 
-                                              "</ol>");
-#   my $approx_matches = parseBetween($response, "<b>Approximate Matches</b>", 
-#                                               "</ol>");
+                                              "</table>");
+#   my $approx_matches = parseBetween($response, "<b>Titles (Approx Matches)</b>", 
+#                                               "</table>");
    # parse movie list from matches
-   my $beg = "<li>";
-   my $end = "</li>";
+   my $beg = "<tr>";
+   my $end = "</tr>";
    my $count = 0;
    my @movies;
 
@@ -513,29 +472,18 @@ sub getMovieList {
       my $type = "";
       my $movienum = "";
 
-      my $link_end = "</a>";
-      $fl_end = index($entry, $link_end);
-      $fl_end += length($link_end);
-      my $lhs = substr($entry, 0, $fl_end);
-      my $rhs = substr($entry, $fl_end);
-
-      if ($lhs =~ m/<a href="\/title\/tt(\d+)\/.*\">(.+)<\/a>/i) {
+      if ($entry =~ m/<a href="\/title\/tt(\d+)\/.*\">(.+)<\/a> \((\d+)\)(?: \((.+)\))?/i) {
           $movienum = $1;
           $title = $2;
+          $year = $3;
+          $type = $4 if ($4);
       } else {
            if (defined $opt_d) {
-               print("Unrecognized entry format\n");
+               print("Unrecognized entry format ($entry)\n");
            }
            next;
       }
 
-      if ($rhs =~ m/\((\d+)\) \((.+)\)/) {
-          $year = $1;
-          $type = $2;
-      } elsif ($rhs =~ m/\((\d+)\)/) {
-          $year = $1;
-      }
-
       my $skip = 0;
 
       # fix broken 'tv=no' option
@@ -634,3 +582,4 @@ elsif (defined $opt_M) {
    }
    getMovieList($query, $options);
 }
+# vim: set expandtab ts=3 sw=3 :
