@@ -1,3 +1,5 @@
+#include <qfileinfo.h>
+
 #include <mythtv/mythcontext.h>
 #include <mythtv/uitypes.h>
 #include <mythtv/mythmediamonitor.h>
@@ -17,7 +19,7 @@
 #include <iterator>
 #include <map>
 
-namespace
+namespace fake_unnamed
 {
     class meta_node
     {
@@ -191,18 +193,18 @@ namespace
         void addEntry(const smart_meta_node &entry)
         {
             entry->setParent(this);
-            m_entires.push_back(entry);
+            m_entries.push_back(entry);
         }
 
         void clear()
         {
             m_subdirs.clear();
-            m_entires.clear();
+            m_entries.clear();
         }
 
         bool empty() const
         {
-            return m_subdirs.empty() && m_entires.empty();
+            return m_subdirs.empty() && m_entries.empty();
         }
 
         int subdir_count() const {
@@ -213,7 +215,7 @@ namespace
         void sort(DirSort dir_sort, EntrySort entry_sort)
         {
             m_subdirs.sort(dir_sort);
-            m_entires.sort(entry_sort);
+            m_entries.sort(entry_sort);
 
             for (meta_dir_list::iterator p = m_subdirs.begin();
                  p != m_subdirs.end(); ++p)
@@ -244,29 +246,48 @@ namespace
 
         entry_iterator entries_begin()
         {
-            return m_entires.begin();
+            return m_entries.begin();
         }
 
         entry_iterator entries_end()
         {
-            return m_entires.end();
+            return m_entries.end();
         }
 
         const_entry_iterator entries_begin() const
         {
-            return m_entires.begin();
+            return m_entries.begin();
         }
 
         const_entry_iterator entries_end() const
         {
-            return m_entires.end();
+            return m_entries.end();
+        }
+
+        // Returns true if this directory or any of its subdirectories
+        // have entries. TODO: cache this value
+        bool has_entries() const
+        {
+            bool ret = m_entries.size();
+
+            if (!ret)
+            {
+                for (meta_dir_list::const_iterator p = m_subdirs.begin();
+                     p != m_subdirs.end(); ++p)
+                {
+                    ret = (*p)->has_entries();
+                    if (ret) break;
+                }
+            }
+
+            return ret;
         }
 
       private:
         QString m_path;
         QString m_name;
         meta_dir_list m_subdirs;
-        meta_data_list m_entires;
+        meta_data_list m_entries;
     };
 
     /// metadata sort functor
@@ -348,7 +369,7 @@ namespace
 
         if (hint)
         {
-            if (metadata->Filename().startsWith(hint->getFQPath()))
+            if (metadata->Filename().startsWith(hint->getFQPath() + "/"))
             {
                 start = hint;
                 insert_chunk =
@@ -356,7 +377,7 @@ namespace
             }
         }
 
-        if (insert_chunk.startsWith(dir->getFQPath()))
+        if (insert_chunk.startsWith(dir->getFQPath() + "/"))
         {
             insert_chunk = metadata->Filename().mid(dir->getFQPath().length());
         }
@@ -408,6 +429,7 @@ namespace
         kOrderItem
     };
 }
+using namespace fake_unnamed;
 
 class VideoListImp
 {
@@ -628,14 +650,17 @@ void VideoListImp::build_generic_tree(GenericTree *dst, meta_dir_node *src,
     for (meta_dir_node::const_dir_iterator dir = src->dirs_begin();
          dir != src->dirs_end(); ++dir)
     {
-        GenericTree *t = addDirNode(dst, (*dir)->getName(), include_updirs);
-        t->setAttribute(kFolderPath, m_folder_id);
-        m_folder_id_to_path.
-                insert(id_string_map::value_type(m_folder_id,
-                                                 (*dir)->getFQPath()));
-        ++m_folder_id;
+        if ((*dir)->has_entries())
+        {
+            GenericTree *t = addDirNode(dst, (*dir)->getName(), include_updirs);
+            t->setAttribute(kFolderPath, m_folder_id);
+            m_folder_id_to_path.
+                    insert(id_string_map::value_type(m_folder_id,
+                                                     (*dir)->getFQPath()));
+            ++m_folder_id;
 
-        build_generic_tree(t, dir->get(), include_updirs);
+            build_generic_tree(t, dir->get(), include_updirs);
+        }
     }
 
     for (meta_dir_node::const_entry_iterator entry = src->entries_begin();
@@ -972,7 +997,7 @@ int VideoListImp::addFileNode(GenericTree *where_to_add, const QString &name,
     return 1;
 }
 
-namespace
+namespace fake_unnamed
 {
     void copy_entries(meta_dir_node &dst, meta_dir_node &src,
                       const VideoFilterSettings &filter)
@@ -1001,15 +1026,14 @@ namespace
         }
     }
 
+    void tree_view_to_flat(meta_dir_node &tree,
+                           VideoListImp::metadata_view_list &flat);
     struct call_tree_flat
     {
         call_tree_flat(VideoListImp::metadata_view_list &list) : m_list(list) {}
 
         void operator()(smart_dir_node &sdn)
         {
-            void tree_view_to_flat(meta_dir_node &,
-                                   VideoListImp::metadata_view_list &);
-
             tree_view_to_flat(*(sdn.get()), m_list);
         }
 
@@ -1084,7 +1108,7 @@ void VideoListImp::update_meta_view(bool flat_list)
     update_flat_index();
 }
 
-namespace
+namespace fake_unnamed
 {
     class dirhandler : public DirectoryHandler
     {
@@ -1094,9 +1118,9 @@ namespace
       public:
         dirhandler(smart_dir_node &directory, const QString &prefix,
                    MetadataListManager::metadata_list &metalist,
-                   free_list &dh_free_list) :
+                   free_list &dh_free_list, bool infer_title) :
             m_directory(directory), m_prefix(prefix), m_metalist(metalist),
-            m_dh_free_list(dh_free_list)
+            m_dh_free_list(dh_free_list), m_infer_title(infer_title)
         {
         }
 
@@ -1106,7 +1130,8 @@ namespace
             (void)fq_dir_name;
             smart_dir_node dir = m_directory->addSubDir(dir_name);
             DirectoryHandler *dh = new dirhandler(dir, m_prefix, m_metalist,
-                                                  m_dh_free_list);
+                                                  m_dh_free_list,
+                                                  m_infer_title);
             m_dh_free_list.push_back(dh);
             return dh;
         }
@@ -1120,8 +1145,14 @@ namespace
             QString file_string(fq_file_name);
 
             MetadataListManager::MetadataPtr myData(new Metadata(file_string));
-            QString title = Metadata::FilenameToTitle(file_string);
-            if (!title.length()) title = file_string.section("/", -1);
+            QFileInfo qfi(file_string);
+            QString title = qfi.baseName(true);
+            if (m_infer_title)
+            {
+                QString tmptitle(Metadata::FilenameToTitle(file_string));
+                if (tmptitle.length())
+                    title = tmptitle;
+            }
             myData->setTitle(title);
             myData->setPrefix(m_prefix);
 
@@ -1135,6 +1166,7 @@ namespace
         const QString &m_prefix;
         MetadataListManager::metadata_list &m_metalist;
         free_list &m_dh_free_list;
+        const bool m_infer_title;
     };
 }
 
@@ -1145,6 +1177,6 @@ void VideoListImp::buildFileList(smart_dir_node &directory,
     FileAssociations::getFileAssociation().getExtensionIgnoreList(ext_list);
 
     dirhandler::free_list fl;
-    dirhandler dh(directory, prefix, metalist, fl);
+    dirhandler dh(directory, prefix, metalist, fl, false);
     ScanVideoDirectory(directory->getFQPath(), &dh, ext_list, m_ListUnknown);
 }
