@@ -2,10 +2,10 @@
 /**
  * Routines that allow mythweb to communicate with mythbackend
  *
- * @url         $URL: svn+ssh://ijr@cvs.mythtv.org/var/lib/svn/trunk/mythplugins/mythweb/includes/mythbackend.php $
- * @date        $Date: 2006-07-15 02:21:36 -0400 (Sat, 15 Jul 2006) $
- * @version     $Revision: 10527 $
- * @author      $Author: xris $
+ * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/includes/mythbackend.php $
+ * @date        $Date: 2006-09-23 21:00:45 -0500 (Sat, 23 Sep 2006) $
+ * @version     $Revision: 11282 $
+ * @author      $Author: bjm $
  * @license     GPL
  *
  * @package     MythWeb
@@ -17,12 +17,12 @@
 
 // MYTH_PROTO_VERSION is defined in libmyth in mythtv/libs/libmyth/mythcontext.h
 // and should be the current MythTV protocol version.
-    define('MYTH_PROTO_VERSION', 30);
+    define('MYTH_PROTO_VERSION', 31);
 
 // NUMPROGRAMLINES is defined in mythtv/libs/libmythtv/programinfo.h and is
 // the number of items in a ProgramInfo QStringList group used by
 // ProgramInfo::ToSringList and ProgramInfo::FromStringList.
-    $NUMPROGRAMLINES = 41;
+    $NUMPROGRAMLINES = 42;
 
 // Keep track of the master backend port/ip
     $Master_Host = get_backend_setting('MasterServerIP');
@@ -273,7 +273,8 @@
                      $show->starttime,              // 38 dummy org airdate
                      '',                            // 39 dummy timestretch
                      ' ',                           // 40 recpriority2
-                     '',                            // 41 trailing separator
+                     ' ',                           // 41 parentid
+                     '',                            // 42 trailing separator
                     );
         $lastmodified = strtotime(backend_command($cmd));
     // Delete outdated images, but not until the show has finished recording
