@@ -2,9 +2,9 @@
 /**
  * The Schedule object and a couple of related subroutines.
  *
- * @url         $URL: svn+ssh://ijr@cvs.mythtv.org/var/lib/svn/trunk/mythplugins/mythweb/includes/recording_schedules.php $
- * @date        $Date: 2006-09-10 17:08:56 -0400 (Sun, 10 Sep 2006) $
- * @version     $Revision: 11113 $
+ * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/includes/recording_schedules.php $
+ * @date        $Date: 2006-09-30 20:03:13 -0500 (Sat, 30 Sep 2006) $
+ * @version     $Revision: 11363 $
  * @author      $Author: xris $
  * @license     GPL
  *
@@ -255,44 +255,44 @@ class Schedule {
                                        VALUES (?,?,?,
                                                FROM_UNIXTIME(?),FROM_UNIXTIME(?),FROM_UNIXTIME(?),FROM_UNIXTIME(?),
                                                ?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?)',
-                         $this->recordid,
-                         $this->type,
+                         _or($this->recordid,      0,          true),
+                         _or($this->type,          0,          true),
                          $this->chanid,
                          $this->starttime,
                          $this->starttime,
                          $this->endtime,
                          $this->endtime,
-                         $this->search,
-                         $this->title,
-                         $this->subtitle,
-                         $this->description,
-                         $this->profile,
-                         $this->recpriority,
-                         $this->category,
-                         $this->maxnewest,
-                         $this->inactive,
-                         $this->maxepisodes,
-                         $this->autoexpire,
-                         $this->startoffset,
-                         $this->endoffset,
-                         $this->recgroup,
-                         $this->dupmethod,
-                         $this->dupin,
-                         $this->station,  // callsign!
-                         $this->seriesid,
-                         $this->programid,
-                         $this->autocommflag,
-                         $this->findday,
-                         $this->findtime,
-                         $this->findid,
-                         $this->autotranscode,
-                         $this->transcoder,
-                         $this->parentid,
-                         $this->tsdefault,
-                         $this->autouserjob1,
-                         $this->autouserjob2,
-                         $this->autouserjob3,
-                         $this->autouserjob4
+                         _or($this->search,        0,          true),
+                         _or($this->title,         'Untitled'      ),
+                         _or($this->subtitle,      ''              ),
+                         _or($this->description,   ''              ),
+                         _or($this->profile,       'Default'       ),
+                         _or($this->recpriority,   0               ),
+                         _or($this->category,      0               ),
+                         _or($this->maxnewest,     0,          true),
+                         _or($this->inactive,      0,          true),
+                         _or($this->maxepisodes,   0,          true),
+                         _or($this->autoexpire,    0,          true),
+                         _or($this->startoffset,   0               ),
+                         _or($this->endoffset,     0               ),
+                         _or($this->recgroup,      'Default'       ),
+                         _or($this->dupmethod,     0,          true),
+                         _or($this->dupin,         15,         true),
+                         _or($this->station,       ''              ),  // callsign!
+                         _or($this->seriesid,      ''              ),
+                         _or($this->programid,     ''              ),
+                         _or($this->autocommflag,  0,          true),
+                         _or($this->findday,       0,          true),
+                         _or($this->findtime,      '00:00:00'      ),
+                         _or($this->findid,        0,          true),
+                         _or($this->autotranscode, 0,          true),
+                         _or($this->transcoder,    0,          true),
+                         _or($this->parentid,      0,          true),
+                         _or($this->tsdefault,     1,          true),
+                         _or($this->autouserjob1,  0,          true),
+                         _or($this->autouserjob2,  0,          true),
+                         _or($this->autouserjob3,  0,          true),
+                         _or($this->autouserjob4,  0,          true)
                         );
     // Get the id that was returned
         $recordid = $sh->insert_id();
