@@ -11,9 +11,9 @@
  * library.  If you would like to inquire about the status of this arrangement,
  * please contact me personally.
  *
- * @url         $URL: svn+ssh://ijr@cvs.mythtv.org/var/lib/svn/trunk/mythplugins/mythweb/includes/utils.php $
- * @date        $Date: 2006-06-26 21:36:28 -0400 (Mon, 26 Jun 2006) $
- * @version     $Revision: 10308 $
+ * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/includes/utils.php $
+ * @date        $Date: 2006-09-16 19:11:56 -0500 (Sat, 16 Sep 2006) $
+ * @version     $Revision: 11219 $
  * @author      $Author: xris $
  * @license     GPL
  *
@@ -325,7 +325,7 @@
     // Global override?
         $video_url = setting('WebVideo_URL');
         if ($video_url)
-            return $video_url;
+            return $video_url.str_replace('%2F', '/', rawurlencode(basename($show->filename)));
     // Mac and Linux just get a link to the streaming module
         if (preg_match('/\b(?:linux|macintosh|mac\s+os\s*x)\b/i', $_SERVER['HTTP_USER_AGENT']))
             return root."pl/stream/$show->chanid/$show->recstartts";
@@ -338,8 +338,8 @@
         }
     // Send the myth url
         else {
-            $video_url = "myth://$Master_Host:$Master_Port"
-                         .str_replace('%2F', '/', rawurlencode(basename($show->filename)));
+            return "myth://$Master_Host:$Master_Port/"
+                   .str_replace('%2F', '/', rawurlencode(basename($show->filename)));
         }
     }
 
