@@ -2,9 +2,9 @@
 /**
  * Initialization routines for the MythWeb Music module
  *
- * @url         $URL: svn+ssh://ijr@cvs.mythtv.org/var/lib/svn/trunk/mythplugins/mythweb/modules/music/init.php $
- * @date        $Date: 2006-03-23 02:46:57 -0500 (Thu, 23 Mar 2006) $
- * @version     $Revision: 9478 $
+ * @url         $URL: http://svn.mythtv.org/svn/branches/release-0-20-fixes/mythplugins/mythweb/modules/music/init.php $
+ * @date        $Date: 2006-09-15 00:08:12 -0500 (Fri, 15 Sep 2006) $
+ * @version     $Revision: 11197 $
  * @author      $Author: xris $
  * @license     GPL
  *
@@ -16,7 +16,7 @@
 // First, we should check to see that MythMusic is configured.
 // Make sure to turn off fatal errors in case the table isn't there.
     $db->disable_fatal_errors();
-    $has_music = $db->query_col('SELECT COUNT(*) FROM musicmetadata');
+    $has_music = $db->query_col('SELECT COUNT(*) FROM music_songs');
     $db->enable_fatal_errors();
     $db->error(false);
 
